@@ -1,8 +1,17 @@
-# -*- coding: utf-8 -*-
-""" MDF v4 constants """
+"""MDF v4 constants"""
+
+from collections.abc import Callable
+from enum import IntEnum
 import re
 import struct
 import sys
+from typing import Literal
+
+from typing_extensions import Buffer
+
+from .blocks_common import UnpackFrom
+
+SUPPORTED_MDF_VERSION = 420
 
 MAX_UINT64 = (1 << 64) - 1
 
@@ -23,6 +32,7 @@ DATA_TYPE_CANOPEN_DATE = 13
 DATA_TYPE_CANOPEN_TIME = 14
 DATA_TYPE_COMPLEX_INTEL = 15
 DATA_TYPE_COMPLEX_MOTOROLA = 16
+DATA_TYPE_STRING_WITH_BOM = 17
 
 VALID_DATA_TYPES = {
     DATA_TYPE_UNSIGNED_INTEL,
@@ -93,6 +103,7 @@ SIGNAL_TYPE_CANOPEN = 2
 SIGNAL_TYPE_STRUCTURE_COMPOSITION = 3
 SIGNAL_TYPE_ARRAY = 4
 SIGNAL_TYPE_BYTEARRAY = 5
+SIGNAL_TYPE_VIRTUAL = 6
 
 SIGNED_INT = {DATA_TYPE_SIGNED_INTEL, DATA_TYPE_SIGNED_MOTOROLA}
 FLOATS = {DATA_TYPE_REAL_INTEL, DATA_TYPE_REAL_MOTOROLA}
@@ -112,6 +123,7 @@ CHANNEL_TYPE_VIRTUAL_MASTER = 3
 CHANNEL_TYPE_SYNC = 4
 CHANNEL_TYPE_MLSD = 5
 CHANNEL_TYPE_VIRTUAL = 6
+CHANNEL_TYPE_VLSC = 7
 
 SYNC_TYPE_NONE = 0
 SYNC_TYPE_TIME = 1
@@ -218,6 +230,10 @@ SOURCE_BUS = 2
 SOURCE_IO = 3
 SOURCE_TOOL = 4
 SOURCE_USER = 5
+SOURCE_VIDEO = 6
+SOURCE_RADAR = 7
+SOURCE_LIDAR = 8
+SOURCE_PROTOCOL = 9
 
 SOURCE_TYPE_TO_STRING = {
     SOURCE_OTHER: "OTHER",
@@ -226,6 +242,10 @@ SOURCE_TYPE_TO_STRING = {
     SOURCE_IO: "IO",
     SOURCE_TOOL: "TOOL",
     SOURCE_USER: "USER",
+    SOURCE_VIDEO: "VIDEO",
+    SOURCE_RADAR: "RADAR",
+    SOURCE_LIDAR: "LIDAR",
+    SOURCE_PROTOCOL: "PROTOCOL",
 }
 
 BUS_TYPE_NONE = 0
@@ -237,6 +257,7 @@ BUS_TYPE_FLEXRAY = 5
 BUS_TYPE_K_LINE = 6
 BUS_TYPE_ETHERNET = 7
 BUS_TYPE_USB = 8
+BUS_LOGGING_TYPES = {BUS_TYPE_CAN, BUS_TYPE_FLEXRAY, BUS_TYPE_K_LINE, BUS_TYPE_LIN}
 
 BUS_TYPE_TO_STRING = {
     BUS_TYPE_NONE: "NONE",
@@ -309,6 +330,7 @@ HL_BLOCK_SIZE = 40
 IDENTIFICATION_BLOCK_SIZE = 64
 HEADER_BLOCK_SIZE = 104
 SR_BLOCK_SIZE = 64
+GD_BLOCK_SIZE = 40
 
 FLAG_ALL_SAMPLES_VALID = 1
 FLAG_INVALIDATION_BIT_VALID = 2
@@ -320,7 +342,11 @@ FLAG_AT_EMBEDDED = 1
 FLAG_AT_COMPRESSED_EMBEDDED = 2
 FLAG_AT_MD5_VALID = 4
 FLAG_DZ_DEFLATE = 0
-FLAG_DZ_TRANPOSED_DEFLATE = 1
+FLAG_DZ_TRANSPOSED_DEFLATE = 1
+FLAG_DZ_ZSTD = 2
+FLAG_DZ_TRANSPOSED_ZSTD = 3
+FLAG_DZ_LZ4 = 4
+FLAG_DZ_TRANSPOSED_LZ4 = 5
 
 FLAG_CA_DYNAMIC_AXIS = 1
 FLAG_CA_INPUT_QUANTITY = 1 << 1
@@ -389,6 +415,11 @@ FLAG_CN_MONOTONOUS = 1 << 11
 FLAG_CN_DEFAULT_X = 1 << 12
 FLAG_CN_EVENT_SIGNAL = 1 << 13
 FLAG_CN_VLSD = 1 << 14
+FLAG_CN_RAW_SENSOR_EVENT = 1 << 15
+FLAG_CN_AUXILIARY_CHANNEL = 1 << 16
+FLAG_CN_DS = 1 << 17
+FLAG_CN_ALIGNMENT_RESET = 1 << 18
+FLAG_CN_PROTOCOL_EVENT = 1 << 19
 
 FLAG_CN_TO_STRING = {
     FLAG_CN_ALL_INVALID: "ALL_INVALID",
@@ -425,12 +456,25 @@ DZ_BLOCK_DEFLATE = 1
 DZ_BLOCK_TRANSPOSED = 2
 DZ_BLOCK_LZ = 3
 
+
+class CompressionAlgorithm(IntEnum):
+    NO_COMPRESSION = 0
+    DEFLATE = 1
+    TRANSPOSED_DEFLATE = 2
+    ZSTD = 3
+    TRANSPOSED_ZSTD = 4
+    LZ4 = 5
+    TRANSPOSED_LZ4 = 6
+
+
 FMT_CHANNEL = "<4sI2Q{}Q4B4I2BH6d"
 FMT_CHANNEL_PARAMS = "<4B4I2BH6d"
+Channel = tuple[int, int, int, int, int, int, int, int, int, int, int, float, float, float, float, float, float]
 
 FMT_CHANNEL_FILTER = "<4s12x4Q32xQ"
-CHANNEL_FILTER_u = struct.Struct(FMT_CHANNEL_FILTER).unpack
-CHANNEL_FILTER_uf = struct.Struct(FMT_CHANNEL_FILTER).unpack_from
+ChannelFilter = tuple[bytes, int, int, int, int, int]
+CHANNEL_FILTER_u: Callable[[Buffer], ChannelFilter] = struct.Struct(FMT_CHANNEL_FILTER).unpack
+CHANNEL_FILTER_uf: UnpackFrom[ChannelFilter] = struct.Struct(FMT_CHANNEL_FILTER).unpack_from
 CHANNEL_FILTER_SIZE = 88
 
 FMT_SIMPLE_CHANNEL = "<4sI10Q4B4I2BH6d"
@@ -466,16 +510,71 @@ KEYS_SIMPLE_CHANNEL = (
     "upper_ext_limit",
 )
 FMT_SIMPLE_CHANNEL_PARAMS = "<8Q4B4I2BH6d"
-SIMPLE_CHANNEL_PARAMS_u = struct.Struct(FMT_SIMPLE_CHANNEL_PARAMS).unpack
-SIMPLE_CHANNEL_PARAMS_uf = struct.Struct(FMT_SIMPLE_CHANNEL_PARAMS).unpack_from
+SimpleChannel = tuple[
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    float,
+    float,
+    float,
+    float,
+    float,
+    float,
+]
+SIMPLE_CHANNEL_PARAMS_u: Callable[[Buffer], SimpleChannel] = struct.Struct(FMT_SIMPLE_CHANNEL_PARAMS).unpack
+SIMPLE_CHANNEL_PARAMS_uf: UnpackFrom[SimpleChannel] = struct.Struct(FMT_SIMPLE_CHANNEL_PARAMS).unpack_from
 SIMPLE_CHANNEL_PACK = struct.Struct(FMT_SIMPLE_CHANNEL).pack
 FMT_SINGLE_ATTACHMENT_CHANNEL = "<4sI11Q4B4I2BH6d"
 SINGLE_ATTACHMENT_CHANNEL_PACK = struct.Struct(FMT_SINGLE_ATTACHMENT_CHANNEL).pack
 FMT_SINGLE_ATTACHMENT_CHANNEL_PARAMS = "<9Q4B4I2BH6d"
-SINGLE_ATTACHMENT_CHANNEL_PARAMS_uf = struct.Struct(
+SingleAttachmentChannel = tuple[
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    int,
+    float,
+    float,
+    float,
+    float,
+    float,
+    float,
+]
+SINGLE_ATTACHMENT_CHANNEL_PARAMS_uf: UnpackFrom[SingleAttachmentChannel] = struct.Struct(
     FMT_SINGLE_ATTACHMENT_CHANNEL_PARAMS
 ).unpack_from
-SINGLE_ATTACHMENT_CHANNEL_PARAMS_u = struct.Struct(
+SINGLE_ATTACHMENT_CHANNEL_PARAMS_u: Callable[[Buffer], SingleAttachmentChannel] = struct.Struct(
     FMT_SINGLE_ATTACHMENT_CHANNEL_PARAMS
 ).unpack
 
@@ -483,6 +582,7 @@ FMT_TEXT_BLOCK = "<4sIQQ{}s"
 KEYS_TEXT_BLOCK = ("id", "reserved0", "block_len", "links_nr", "text")
 
 FMT_SOURCE_INFORMATION = "<4sI5Q3B5s"
+SourceInformation = tuple[bytes, int, int, int, int, int, int, int, int, int, bytes]
 KEYS_SOURCE_INFORMATION = (
     "id",
     "reserved0",
@@ -499,6 +599,7 @@ KEYS_SOURCE_INFORMATION = (
 SOURCE_INFORMATION_PACK = struct.Struct(FMT_SOURCE_INFORMATION).pack
 
 FMT_CHANNEL_GROUP = "<4sI10Q2H3I"
+ChannelGroup = tuple[bytes, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int]
 KEYS_CHANNEL_GROUP = (
     "id",
     "reserved0",
@@ -518,11 +619,12 @@ KEYS_CHANNEL_GROUP = (
     "samples_byte_nr",
     "invalidation_bytes_nr",
 )
-CHANNEL_GROUP_u = struct.Struct(FMT_CHANNEL_GROUP).unpack
-CHANNEL_GROUP_uf = struct.Struct(FMT_CHANNEL_GROUP).unpack_from
+CHANNEL_GROUP_u: Callable[[Buffer], ChannelGroup] = struct.Struct(FMT_CHANNEL_GROUP).unpack
+CHANNEL_GROUP_uf: UnpackFrom[ChannelGroup] = struct.Struct(FMT_CHANNEL_GROUP).unpack_from
 CHANNEL_GROUP_p = struct.Struct(FMT_CHANNEL_GROUP).pack
 
 FMT_CHANNEL_GROUP_SHORT = "<8Q2H3I"
+ChannelGroupShort = tuple[int, int, int, int, int, int, int, int, int, int, int, int, int]
 KEYS_CHANNEL_GROUP_SHORT = (
     "next_cg_addr",
     "first_ch_addr",
@@ -538,11 +640,12 @@ KEYS_CHANNEL_GROUP_SHORT = (
     "samples_byte_nr",
     "invalidation_bytes_nr",
 )
-CHANNEL_GROUP_SHORT_u = struct.Struct(FMT_CHANNEL_GROUP_SHORT).unpack
-CHANNEL_GROUP_SHORT_uf = struct.Struct(FMT_CHANNEL_GROUP_SHORT).unpack_from
+CHANNEL_GROUP_SHORT_u: Callable[[Buffer], ChannelGroupShort] = struct.Struct(FMT_CHANNEL_GROUP_SHORT).unpack
+CHANNEL_GROUP_SHORT_uf: UnpackFrom[ChannelGroupShort] = struct.Struct(FMT_CHANNEL_GROUP_SHORT).unpack_from
 CHANNEL_GROUP_SHORT_p = struct.Struct(FMT_CHANNEL_GROUP_SHORT).pack
 
 FMT_CHANNEL_GROUP_RM = "<4sI11Q2H3I"
+ChannelGroupRm = tuple[bytes, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int]
 KEYS_CHANNEL_GROUP_RM = (
     "id",
     "reserved0",
@@ -563,11 +666,12 @@ KEYS_CHANNEL_GROUP_RM = (
     "samples_byte_nr",
     "invalidation_bytes_nr",
 )
-CHANNEL_GROUP_RM_u = struct.Struct(FMT_CHANNEL_GROUP_RM).unpack
-CHANNEL_GROUP_RM_uf = struct.Struct(FMT_CHANNEL_GROUP_RM).unpack_from
+CHANNEL_GROUP_RM_u: Callable[[Buffer], ChannelGroupRm] = struct.Struct(FMT_CHANNEL_GROUP_RM).unpack
+CHANNEL_GROUP_RM_uf: UnpackFrom[ChannelGroupRm] = struct.Struct(FMT_CHANNEL_GROUP_RM).unpack_from
 CHANNEL_GROUP_RM_p = struct.Struct(FMT_CHANNEL_GROUP_RM).pack
 
 FMT_CHANNEL_GROUP_RM_SHORT = "<9Q2H3I"
+ChannelGroupRmShort = tuple[int, int, int, int, int, int, int, int, int, int, int, int, int, int]
 KEYS_CHANNEL_GROUP_RM_SHORT = (
     "next_cg_addr",
     "first_ch_addr",
@@ -584,24 +688,27 @@ KEYS_CHANNEL_GROUP_RM_SHORT = (
     "samples_byte_nr",
     "invalidation_bytes_nr",
 )
-CHANNEL_GROUP_RM_SHORT_u = struct.Struct(FMT_CHANNEL_GROUP_RM_SHORT).unpack
-CHANNEL_GROUP_RM_SHORT_uf = struct.Struct(FMT_CHANNEL_GROUP_RM_SHORT).unpack_from
+CHANNEL_GROUP_RM_SHORT_u: Callable[[Buffer], ChannelGroupRmShort] = struct.Struct(FMT_CHANNEL_GROUP_RM_SHORT).unpack
+CHANNEL_GROUP_RM_SHORT_uf: UnpackFrom[ChannelGroupRmShort] = struct.Struct(FMT_CHANNEL_GROUP_RM_SHORT).unpack_from
 CHANNEL_GROUP_RM_SHORT_p = struct.Struct(FMT_CHANNEL_GROUP_RM_SHORT).pack
 
 FMT_DATA_BLOCK = "<4sI2Q{}s"
 KEYS_DATA_BLOCK = ("id", "reserved0", "block_len", "links_nr", "data")
 
 FMT_COMMON = "<4sI2Q"
-COMMON_u = struct.Struct(FMT_COMMON).unpack
-COMMON_uf = struct.Struct(FMT_COMMON).unpack_from
+Common = tuple[bytes, int, int, int]
+COMMON_u: Callable[[Buffer], Common] = struct.Struct(FMT_COMMON).unpack
+COMMON_uf: UnpackFrom[Common] = struct.Struct(FMT_COMMON).unpack_from
 COMMON_p = struct.Struct(FMT_COMMON).pack
 
 FMT_COMMON_SHORT = "<4s4xQ"
-COMMON_SHORT_u = struct.Struct(FMT_COMMON_SHORT).unpack
-COMMON_SHORT_uf = struct.Struct(FMT_COMMON_SHORT).unpack_from
+CommonShort = tuple[bytes, int]
+COMMON_SHORT_u: Callable[[Buffer], CommonShort] = struct.Struct(FMT_COMMON_SHORT).unpack
+COMMON_SHORT_uf: UnpackFrom[CommonShort] = struct.Struct(FMT_COMMON_SHORT).unpack_from
 COMMON_SHORT_p = struct.Struct(FMT_COMMON_SHORT).pack
 
 FMT_FILE_HISTORY = "<4sI5Q2hB3s"
+FileHistory = tuple[bytes, int, int, int, int, int, int, int, int, int, bytes]
 KEYS_FILE_HISTORY = (
     "id",
     "reserved0",
@@ -617,6 +724,7 @@ KEYS_FILE_HISTORY = (
 )
 
 FMT_DATA_GROUP = "<4sI6QB7s"
+DataGroup = tuple[bytes, int, int, int, int, int, int, int, int, bytes]
 KEYS_DATA_GROUP = (
     "id",
     "reserved0",
@@ -629,8 +737,8 @@ KEYS_DATA_GROUP = (
     "record_id_len",
     "reserved1",
 )
-DATA_GROUP_u = struct.Struct(FMT_DATA_GROUP).unpack
-DATA_GROUP_uf = struct.Struct(FMT_DATA_GROUP).unpack_from
+DATA_GROUP_u: Callable[[Buffer], DataGroup] = struct.Struct(FMT_DATA_GROUP).unpack
+DATA_GROUP_uf: UnpackFrom[DataGroup] = struct.Struct(FMT_DATA_GROUP).unpack_from
 DATA_GROUP_p = struct.Struct(FMT_DATA_GROUP).pack
 
 FMT_DATA_EQUAL_LIST = "<4sI2Q{}QB3sIQ"
@@ -656,15 +764,17 @@ KEYS_CONVERSION_NONE = (
 )
 CONVERSION_NONE_PACK = struct.Struct(FMT_CONVERSION_NONE).pack
 FMT_CONVERSION_NONE_INIT = "<4Q2B3H2d"
-CONVERSION_NONE_INIT_u = struct.Struct(FMT_CONVERSION_NONE_INIT).unpack
-CONVERSION_NONE_INIT_uf = struct.Struct(FMT_CONVERSION_NONE_INIT).unpack_from
+ConversionNoneInit = tuple[int, int, int, int, int, int, int, int, int, float, float]
+CONVERSION_NONE_INIT_u: Callable[[Buffer], ConversionNoneInit] = struct.Struct(FMT_CONVERSION_NONE_INIT).unpack
+CONVERSION_NONE_INIT_uf: UnpackFrom[ConversionNoneInit] = struct.Struct(FMT_CONVERSION_NONE_INIT).unpack_from
 
 FMT_CONVERSION_LINEAR = FMT_CONVERSION_NONE + "2d"
 CONVERSION_LINEAR_PACK = struct.Struct(FMT_CONVERSION_LINEAR).pack
-KEYS_CONVERSION_LINEAR = KEYS_CONVERSION_NONE + ("b", "a")
+KEYS_CONVERSION_LINEAR = (*KEYS_CONVERSION_NONE, "b", "a")
 FMT_CONVERSION_LINEAR_INIT = "<4Q2B3H4d"
-CONVERSION_LINEAR_INIT_u = struct.Struct(FMT_CONVERSION_LINEAR_INIT).unpack
-CONVERSION_LINEAR_INIT_uf = struct.Struct(FMT_CONVERSION_LINEAR_INIT).unpack_from
+ConversionLinearInit = tuple[int, int, int, int, int, int, int, int, int, float, float, float, float]
+CONVERSION_LINEAR_INIT_u: Callable[[Buffer], ConversionLinearInit] = struct.Struct(FMT_CONVERSION_LINEAR_INIT).unpack
+CONVERSION_LINEAR_INIT_uf: UnpackFrom[ConversionLinearInit] = struct.Struct(FMT_CONVERSION_LINEAR_INIT).unpack_from
 
 FMT_CONVERSION_ALGEBRAIC = "<4sI7Q2B3H2d"
 CONVERSION_ALGEBRAIC_PACK = struct.Struct(FMT_CONVERSION_ALGEBRAIC).pack
@@ -687,17 +797,21 @@ KEYS_CONVERSION_ALGEBRAIC = (
     "max_phy_value",
 )
 FMT_CONVERSION_ALGEBRAIC_INIT = "<5Q2B3H2d"
+ConversionAlgebraicInit = tuple[int, int, int, int, int, int, int, int, int, int, float, float]
 
 FMT_CONVERSION_RAT = FMT_CONVERSION_NONE + "6d"
 CONVERSION_RAT_PACK = struct.Struct(FMT_CONVERSION_RAT).pack
-KEYS_CONVERSION_RAT = KEYS_CONVERSION_NONE + ("P1", "P2", "P3", "P4", "P5", "P6")
-
-FMT_CONVERSION_RAT_INIT = "<4Q2B3H8d"
+KEYS_CONVERSION_RAT = (*KEYS_CONVERSION_NONE, "P1", "P2", "P3", "P4", "P5", "P6")
 
 FMT_CONVERSION_RAT_INIT = "<4Q2B3H8d"
+ConversionRatInit = tuple[
+    int, int, int, int, int, int, int, int, int, float, float, float, float, float, float, float, float
+]
 
 FMT_HEADER_BLOCK = "<4sI9Q2h4B2Q"
+HeaderBlock = tuple[bytes, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int, int]
 FMT_IDENTIFICATION_BLOCK = "<8s8s8s4sH30s2H"
+IdentificationBlock = tuple[bytes, bytes, bytes, bytes, int, bytes, int, int]
 
 KEYS_HEADER_BLOCK = (
     "id",
@@ -733,6 +847,7 @@ KEYS_IDENTIFICATION_BLOCK = (
 )
 
 FMT_AT_COMMON = "<4sI6Q2HI16s2Q"
+AtCommon = tuple[bytes, int, int, int, int, int, int, int, int, int, int, bytes, int, int]
 KEYS_AT_BLOCK = (
     "id",
     "reserved0",
@@ -750,10 +865,11 @@ KEYS_AT_BLOCK = (
     "embedded_size",
     "embedded_data",
 )
-AT_COMMON_u = struct.Struct(FMT_AT_COMMON).unpack
-AT_COMMON_uf = struct.Struct(FMT_AT_COMMON).unpack_from
+AT_COMMON_u: Callable[[Buffer], AtCommon] = struct.Struct(FMT_AT_COMMON).unpack
+AT_COMMON_uf: UnpackFrom[AtCommon] = struct.Struct(FMT_AT_COMMON).unpack_from
 
 FMT_DZ_COMMON = "<4sI2Q2s2BI2Q"
+DzCommon = tuple[bytes, int, int, int, bytes, int, int, int, int, int]
 KEYS_DZ_BLOCK = (
     "id",
     "reserved0",
@@ -770,11 +886,13 @@ KEYS_DZ_BLOCK = (
 DZ_COMMON_p = struct.Struct(FMT_DZ_COMMON).pack
 
 FMT_DZ_INFO_COMMON = "<B1xI2Q"
+DzInfoCommon = tuple[int, int, int, int]
 DZ_INFO_COMMON_OFFSET = 26
-DZ_COMMON_INFO_u = struct.Struct(FMT_DZ_INFO_COMMON).unpack
-DZ_COMMON_INFO_uf = struct.Struct(FMT_DZ_INFO_COMMON).unpack_from
+DZ_COMMON_INFO_u: Callable[[Buffer], DzInfoCommon] = struct.Struct(FMT_DZ_INFO_COMMON).unpack
+DZ_COMMON_INFO_uf: UnpackFrom[DzInfoCommon] = struct.Struct(FMT_DZ_INFO_COMMON).unpack_from
 
 FMT_HL_BLOCK = "<4sI3QHB5s"
+HlBlock = tuple[bytes, int, int, int, int, int, int, bytes]
 KEYS_HL_BLOCK = (
     "id",
     "reserved0",
@@ -787,6 +905,7 @@ KEYS_HL_BLOCK = (
 )
 
 FMT_EVENT_PARAMS = "<5B3sI2Hqd"
+EventParams = tuple[int, int, int, int, int, bytes, int, int, int, int, float]
 FMT_EVENT = "<4sI2Q{}Q5B3sI2Hqd"
 
 FMT_SR_BLOCK = "<4sI5Qd2B6s"
@@ -804,6 +923,21 @@ KEYS_SR_BLOCK = (
     "reserved1",
 )
 
+FMT_GD_BLOCK = "<4sI3QH6s"
+GdBlock = tuple[bytes, int, int, int, int, int, bytes]
+KEYS_GD_BLOCK = (
+    "id",
+    "reserved0",
+    "block_len",
+    "links_nr",
+    "gd_addr",
+    "gd_version",
+    "reserved1",
+)
+GD_u: Callable[[Buffer], GdBlock] = struct.Struct(FMT_GD_BLOCK).unpack
+GD_uf: UnpackFrom[GdBlock] = struct.Struct(FMT_GD_BLOCK).unpack_from
+GD_p = struct.Struct(FMT_GD_BLOCK).pack
+
 ASAM_XML_NAMESPACE = "{http://www.asam.net/mdf/v4}"
 
 CAN_ID_PATTERN = re.compile(r"(?i:can)(?P<id>\d+)")
@@ -874,3 +1008,5 @@ for chn in range(20):
 
 for chk in range(256):
     sys.intern(f"Checksum 0x{chk:02X}")
+
+Version = Literal["4.00", "4.10", "4.11", "4.20"]
