@@ -1,38 +1,39 @@
-# -*- coding: utf-8 -*-
-from collections import defaultdict
-from copy import deepcopy
+import bisect
+import builtins
+import collections
+from collections import namedtuple
+import ctypes
 from datetime import datetime
-from functools import reduce
+from functools import partial, reduce
 import inspect
 from io import StringIO
-import json
+import itertools
 import math
 import os
-from pathlib import Path
 import random
 import re
+import struct
 import sys
-from textwrap import dedent, indent
+from textwrap import indent
 from threading import Thread
-from time import perf_counter, sleep
+from time import sleep
 import traceback
 from traceback import format_exc
 
-import lxml
-import natsort
-from numexpr import evaluate
 import numpy as np
 import pandas as pd
 from pyqtgraph import functions as fn
 from PySide6 import QtCore, QtGui, QtWidgets
-from PySide6.QtCore import QObject, QRunnable, QThreadPool, QTimer, Signal, Slot
 
-from ..blocks import v4_constants as v4c
-from ..blocks.conversion_utils import from_dict
 from ..blocks.options import FloatInterpolation, IntegerInterpolation
-from ..mdf import MDF, MDF2, MDF3, MDF4
+from ..blocks.utils import Terminated
 from ..signal import Signal
 from .dialogs.error_dialog import ErrorDialog
+from .dialogs.messagebox import MessageBox
+
+_BUILTINS = vars(builtins).copy()
+for key in ("breakpoint", "compile", "eval", "exec", "input", "open"):
+    _BUILTINS.pop(key, None)
 
 ERROR_ICON = None
 RANGE_INDICATOR_ICON = None
@@ -40,20 +41,8 @@ NO_ERROR_ICON = None
 
 COMPUTED_FUNCTION_ERROR_VALUE = float("nan")
 
-
-COLORS = [
-    "#1f77b4",
-    "#ff7f0e",
-    "#2ca02c",
-    "#d62728",
-    "#9467bd",
-    "#8c564b",
-    "#e377c2",
-    "#7f7f7f",
-    "#bcbd22",
-    "#17becf",
-]
-COLORS_COUNT = len(COLORS)
+SUPPORTED_FILE_EXTENSIONS = {".csv", ".zip", ".erg", ".dat", ".mdf", ".mf4", ".mf4z"}
+SUPPORTED_BUS_DATABASE_EXTENSIONS = {".arxml", ".dbc", ".xml"}
 
 GREEN = "#599e5e"
 BLUE = "#61b2e2"
@@ -62,107 +51,114 @@ SCROLLBAR_STYLE = """
 QTreeWidget {{ font-size: {font_size}pt; }}
 
 QScrollBar:vertical {{
-    border: 1px solid #61b2e2;
-    background: {background};
+    border: 1px solid {color};
+    background: palette(window);
     width: 14px;
     margin: 14px 0px 14px 0px;
 }}
 QScrollBar::handle:vertical {{
-    border: 1px solid  {background};
-    background: #61b2e2;
+    border: 1px solid  palette(window);
+    background: {color};
     min-height: 40px;
     width: 6px;
 }}
 
 QScrollBar::add-line:vertical {{
-    border: 1px solid #61b2e2;
-    background: {background};
+    border: 1px solid {color};
+    background: palette(window);
     height: 13px;
     subcontrol-position: bottom;
     subcontrol-origin: margin;
 }}
 QScrollBar::sub-line:vertical {{
-    border: 1px solid #61b2e2;
-    background: {background};
+    border: 1px solid {color};
+    background: palette(window);
     height: 13px;
     subcontrol-position: top;
     subcontrol-origin: margin;
 }}
 
 QScrollBar:up-arrow:vertical {{
-    image: url(:up.png);
-    width: 13px;
-    height: 13px;
+    background: {color};
+    width: 4px;
+    height: 4px;
 }}
 QScrollBar:down-arrow:vertical {{
-    image: url(:down.png);
-    width: 13px;
-    height: 13px;
+    background: {color};
+    width: 4px;
+    height: 4px;
 }}
 
 
 QScrollBar:horizontal {{
-    border: 1px solid #61b2e2;
-    background: {background};
+    border: 1px solid {color};
+    background: palette(window);
     height: 14px;
     margin: 0px 14px 0px 14px;
 }}
 QScrollBar::handle:horizontal {{
-    border: 1px solid  {background};
-    background: #61b2e2;
+    border: 1px solid  palette(window);
+    background: {color};
     min-width: 40px;
     height: 14px;
 }}
 QScrollBar::add-line:horizontal {{
-    border: 1px solid #61b2e2;
-    background: {background};
+    border: 1px solid {color};
+    background: palette(window);
     width: 13px;
     subcontrol-position: right;
     subcontrol-origin: margin;
 }}
 QScrollBar::sub-line:horizontal {{
-    border: 1px solid #61b2e2;
-    background: {background};
+    border: 1px solid {color};
+    background: palette(window);
     width: 13 px;
     subcontrol-position: left;
     subcontrol-origin: margin;
 }}
 
 QScrollBar:left-arrow:horizontal {{
-    image: url(:left2.png);
-    width: 13px;
-    height: 13px;
+    background: {color};
+    width: 4px;
+    height: 4px;
 }}
 QScrollBar:right-arrow:horizontal {{
-    image: url(:right2.png);
-    width: 13px;
-    height: 13px;
+    background: {color};
+    width: 4px;
+    height: 4px;
 }}"""
 
 COMPARISON_NAME = re.compile(r"(\s*\d+:)?(?P<name>.+)")
 SIG_RE = re.compile(r"\{\{(?!\}\})(?P<name>.*?)\}\}")
 
-TERMINATED = object()
-
 FONT_SIZE = [6, 7, 8, 9, 10, 11, 12, 14, 16, 18, 20, 22, 24, 26, 28, 36, 48, 72]
 VARIABLE = re.compile(r"(?P<var>\{\{[^}]+\}\})")
 VARIABLE_GET_DATA = re.compile(r"get_data\s*\(\s*\"(?P<var>[^\"]+)")
 C_FUNCTION = re.compile(r"\s+(?P<function>\S+)\s*\(\s*struct\s+DATA\s+\*data\s*\)")
 FUNC_NAME = re.compile(r"def\s+(?P<name>\S+)\s*\(")
+IMPORT = re.compile(r"^\s*import\s+")
+IMPORT_INNER = re.compile(r";\s*import\s+")
+FROM_IMPORT = re.compile(r"^\s*from\s+\S+\s+import\s+")
+FROM_INNER_IMPORT = re.compile(r";\s*from\s+\S+\s+import\s+")
+
+COMPRESSION_OPTIONS = {
+    "4.10": ("no compression", "deflate", "transposed deflate"),
+    "4.20": ("no compression", "deflate", "transposed deflate"),
+    "4.30": ("no compression", "deflate", "transposed deflate", "zstd", "transposed zstd", "lz4", "transposed lz4"),
+}
 
 
 def excepthook(exc_type, exc_value, tracebackobj):
-    """
-    Global function to catch unhandled exceptions.
+    """Global function to catch unhandled exceptions.
 
     Parameters
     ----------
     exc_type : str
-        exception type
+        Exception type.
     exc_value : int
-        exception value
+        Exception value.
     tracebackobj : traceback
-        traceback object
+        Traceback object.
     """
     separator = "-" * 80
     notice = "The following error was triggered:"
@@ -179,54 +175,46 @@ def excepthook(exc_type, exc_value, tracebackobj):
     msg = "\n".join(sections)
 
     print("".join(traceback.format_tb(tracebackobj)))
-    print("{0}: {1}".format(exc_type, exc_value))
+    print(f"{exc_type}: {exc_value}")
 
-    ErrorDialog(
-        message=errmsg, trace=msg, title="The following error was triggered"
-    ).exec_()
+    ErrorDialog(message=errmsg, trace=msg, title="The following error was triggered").exec_()
 
 
-def run_thread_with_progress(
-    widget, target, kwargs, factor=100, offset=0, progress=None
-):
-    termination_request = False
-
+def run_thread_with_progress(widget, target, kwargs, factor=100, offset=0, progress=None):
     thr = WorkerThread(target=target, kwargs=kwargs)
 
     thr.start()
 
     while widget.progress is None and thr.is_alive():
-        sleep(0.1)
+        sleep(0.02)
 
     while thr.is_alive():
-        if not progress.wasCanceled():
+        if progress and not progress.wasCanceled():
             if widget.progress is not None:
                 if widget.progress != (0, 0):
-                    progress.setValue(
-                        int(widget.progress[0] / widget.progress[1] * factor) + offset
-                    )
+                    progress.setValue(int(widget.progress[0] / widget.progress[1] * factor) + offset)
                 else:
                     progress.setRange(0, 0)
         QtCore.QCoreApplication.processEvents()
         sleep(0.1)
 
-    progress.setValue(factor + offset)
+    if progress:
+        progress.setValue(factor + offset)
 
     if thr.error:
+        if isinstance(thr.error, Terminated):
+            raise thr.error
         widget.progress = None
-        progress.cancel()
+        if progress:
+            progress.cancel()
         raise Exception(thr.error)
 
     widget.progress = None
 
-    if termination_request:
-        return TERMINATED
-    else:
-        return thr.output
+    return thr.output
 
 
-class WorkerSignals(QtCore.QObject):
-    finished = QtCore.Signal()
+class QWorkerThread(QtCore.QThread):
     error = QtCore.Signal(object)
     result = QtCore.Signal(object)
 
@@ -238,69 +226,113 @@ class WorkerSignals(QtCore.QObject):
     setMaximum = QtCore.Signal(int)
     setValue = QtCore.Signal(int)
 
+    SIGNALS_TEMPLATE = namedtuple(
+        "SIGNALS_TEMPLATE",
+        [
+            "finished",
+            "error",
+            "result",
+            "setLabelText",
+            "setWindowTitle",
+            "setWindowIcon",
+            "setMinimum",
+            "setMaximum",
+            "setValue",
+        ],
+    )
 
-class Worker(QtCore.QRunnable):
     def __init__(self, function, *args, **kwargs):
-        super().__init__()
+        super().__init__(parent=kwargs.pop("parent", None))
         self.function = function
         self.args = args
+
+        self.signals = self.SIGNALS_TEMPLATE(
+            self.finished,
+            self.error,
+            self.result,
+            self.setLabelText,
+            self.setWindowTitle,
+            self.setWindowIcon,
+            self.setMinimum,
+            self.setMaximum,
+            self.setValue,
+        )
+
+        args = inspect.signature(function)
+        if "progress" in args.parameters:
+            kwargs["progress"] = self
+
         self.kwargs = kwargs
-        self.signals = WorkerSignals()
         self.stop = False
-        self.TERMINATED = TERMINATED
 
-        # Add the qrunner to the keyword arguments
-        kwargs["progress"] = self
-
-    @QtCore.Slot()
     def run(self):
+        """
+        Your code goes in this method
+        """
         try:
             result = self.function(*self.args, **self.kwargs)
-        except Exception:
+        except:
             traceback.print_exc()
             exctype, value = sys.exc_info()[:2]
-            self.signals.error.emit((exctype, value, traceback.format_exc()))
+            self.error.emit((exctype, value, traceback.format_exc()))
         else:
-            self.signals.result.emit(result)
+            self.result.emit(result)
         finally:
-            self.signals.finished.emit()
+            self.kwargs = self.args = None
+
+    def requestInterruption(self):
+        self.stop = True
 
 
 class ProgressDialog(QtWidgets.QProgressDialog):
-    finished = QtCore.Signal()
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.threadpool = QThreadPool()
-        self.worker = None
+        self.thread = None
         self.error = None
         self.result = None
-        self.thread_finished = True
+        self.close_on_finish = True
+        self.hide_on_finish = False
 
-    def run_thread_with_progress(self, target, args, kwargs):
+        self.setMinimumDuration(0)
+
+        self.canceled.connect(partial(self.close, reject=True))
+
+    def run_thread_with_progress(
+        self, target, args, kwargs, wait_here=False, close_on_finish=True, hide_on_finish=False
+    ):
         self.show()
         self.result = None
         self.error = None
         self.thread_finished = False
 
-        self.worker = Worker(target, *args, **kwargs)
-        self.worker.signals.result.connect(self.receive_result)
-        self.worker.signals.finished.connect(self.thread_complete)
-        self.worker.signals.error.connect(self.receive_error)
+        self.close_on_finish = close_on_finish
+        self.hide_on_finish = hide_on_finish
 
-        self.worker.signals.setLabelText.connect(self.setLabelText)
-        self.worker.signals.setWindowIcon.connect(self.setWindowIcon)
-        self.worker.signals.setWindowTitle.connect(self.setWindowTitle)
-        self.worker.signals.setValue.connect(self.setValue)
-        self.worker.signals.setMinimum.connect(self.setMinimum)
-        self.worker.signals.setMaximum.connect(self.setMaximum)
+        self.thread = QWorkerThread(target, *args, parent=self, **kwargs)
+        self.thread.result.connect(self.receive_result)
+        self.thread.finished.connect(self.thread_complete)
+        self.thread.error.connect(self.receive_error)
+        self.thread.setLabelText.connect(self.setLabelText)
+        self.thread.setWindowIcon.connect(self.setWindowIcon)
+        self.thread.setWindowTitle.connect(self.setWindowTitle)
+        self.thread.setValue.connect(self.setValue)
+        self.thread.setMinimum.connect(self.setMinimum)
+        self.thread.setMaximum.connect(self.setMaximum)
 
-        self.canceled.connect(self._canceled)
+        self.thread.start()
 
-        self.threadpool.start(self.worker)
+        if wait_here:
+            loop = QtCore.QEventLoop()
+            self.thread.finished.connect(loop.quit)
+            loop.exec()
 
-    def _canceled(self):
-        self.close()
+        return self.result
+
+    def setLabelText(self, text):
+        super().setLabelText(text)
+
+    def processEvents(self):
+        pass
 
     def receive_result(self, result):
         self.result = result
@@ -309,42 +341,67 @@ class ProgressDialog(QtWidgets.QProgressDialog):
         self.error = error
 
     def thread_complete(self):
-        self.finished.emit(self.parent)
-        self.thread_finished = True
-        super().close()
+        self.processEvents()
+        if self.hide_on_finish:
+            self.hide()
 
-    def cancel(self):
-        super().cancel()
-        self.destroy()
+        self.thread.result.disconnect(self.receive_result)
+        self.thread.finished.disconnect(self.thread_complete)
+        self.thread.error.disconnect(self.receive_error)
+        self.thread.setLabelText.disconnect(self.setLabelText)
+        self.thread.setWindowIcon.disconnect(self.setWindowIcon)
+        self.thread.setWindowTitle.disconnect(self.setWindowTitle)
+        self.thread.setValue.disconnect(self.setValue)
+        self.thread.setMinimum.disconnect(self.setMinimum)
+        self.thread.setMaximum.disconnect(self.setMaximum)
+        self.thread = None
 
-    def close(self):
-        while not self.thread_finished:
-            self.worker.stop = True
-            sleep(0.01)
-            QtCore.QCoreApplication.processEvents()
-        self.destroy()
+        if self.close_on_finish:
+            QtCore.QTimer.singleShot(50, self.close)
+
+    def close(self, reject=False):
+        if self.thread and not self.thread.isFinished():
+            loop = QtCore.QEventLoop()
+            self.thread.finished.connect(loop.quit)
+            self.thread.requestInterruption()
+            loop.exec()
+
+        if reject:
+            self.reject()
+        else:
+            self.accept()
+
+        self.hide()
+
+    def exec(self):
+        super().exec()
+        self.hide()
 
     def keyPressEvent(self, event):
-        if (
-            event.key() == QtCore.Qt.Key_Escape
-            and event.modifiers() == QtCore.Qt.NoModifier
-        ):
+        if event.key() == QtCore.Qt.Key.Key_Escape and event.modifiers() == QtCore.Qt.KeyboardModifier.NoModifier:
+            event.accept()
             self.close()
         else:
             super().keyPressEvent(event)
 
+    def setWindowIcon(self, icon):
+        if isinstance(icon, str):
+            icon_name = icon
+            icon = QtGui.QIcon()
+            icon.addPixmap(QtGui.QPixmap(f":/{icon_name}.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
+
+        super().setWindowIcon(icon)
+
 
 def setup_progress(parent, title="", message="", icon_name="", autoclose=False):
-    progress = ProgressDialog(message, "Cancel", 0, 100, parent)
+    progress = ProgressDialog(message, "Cancel", 0, 0, parent)
 
-    progress.setWindowModality(QtCore.Qt.ApplicationModal)
+    progress.setWindowModality(QtCore.Qt.WindowModality.ApplicationModal)
     progress.setCancelButton(None)
     progress.setAutoClose(autoclose)
     progress.setWindowTitle(title)
     icon = QtGui.QIcon()
-    icon.addPixmap(
-        QtGui.QPixmap(f":/{icon_name}.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-    )
+    icon.addPixmap(QtGui.QPixmap(f":/{icon_name}.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
     progress.setWindowIcon(icon)
     progress.setMinimumWidth(600)
 
@@ -362,6 +419,8 @@ class WorkerThread(Thread):
     def run(self):
         try:
             self.output = self._target(*self._args, **self._kwargs)
+        except Terminated as error:
+            self.error = error
         except:
             self.error = traceback.format_exc()
 
@@ -373,12 +432,16 @@ def get_data_function(signals, fill_0_for_missing_computation_channels):
                 signals[name]
                 .interp(
                     [t],
-                    integer_interpolation_mode=IntegerInterpolation.REPEAT_PREVIOUS_SAMPLE
-                    if not interpolated
-                    else IntegerInterpolation.LINEAR_INTERPOLATION,
-                    float_interpolation_mode=FloatInterpolation.REPEAT_PREVIOUS_SAMPLE
-                    if not interpolated
-                    else FloatInterpolation.LINEAR_INTERPOLATION,
+                    integer_interpolation_mode=(
+                        IntegerInterpolation.REPEAT_PREVIOUS_SAMPLE
+                        if not interpolated
+                        else IntegerInterpolation.LINEAR_INTERPOLATION
+                    ),
+                    float_interpolation_mode=(
+                        FloatInterpolation.REPEAT_PREVIOUS_SAMPLE
+                        if not interpolated
+                        else FloatInterpolation.LINEAR_INTERPOLATION
+                    ),
                 )
                 .samples
             )
@@ -401,7 +464,18 @@ def compute_signal(
     measured_signals,
     all_timebase,
     functions,
+    global_variables="",
 ):
+    required_channels = {}
+    for key, sig in measured_signals.items():
+        signal = sig.physical(copy=False, ignore_value2text_conversions=True)
+        if signal.samples.dtype.kind in "fui":
+            required_channels[key] = signal
+        else:
+            required_channels[key] = sig
+
+    measured_signals = required_channels
+
     type_ = description["type"]
 
     try:
@@ -411,14 +485,19 @@ def compute_signal(
                 f"{description['function']} not found in the user defined functions",
             )
 
-            _globals = {
-                "math": math,
-                "np": np,
-                "pd": pd,
+            _globals = generate_python_function_globals()
+
+            trace = generate_python_variables(global_variables, in_globals=_globals)
+
+            if trace:
+                raise Exception(trace)
+
+            numeric_global_variables = {
+                name: float(val) for name, val in _globals.items() if isinstance(val, (int, float))
             }
 
             for function_name, definition in functions.items():
-                _func, _trace = generate_python_function(definition, _globals)
+                _func, _trace = generate_python_function(definition, in_globals=_globals)
 
                 if function_name == description["function"]:
                     func, trace = _func, _trace
@@ -435,18 +514,41 @@ def compute_signal(
                         signals.append(measured_signals[name])
                         found_args.append(arg)
                         break
+                    else:
+                        found_numeric = False
+                        for base in (10, 16, 2):
+                            try:
+                                value = int(name, base)
+                                signals.append(value)
+                                found_args.append(arg)
+                                found_numeric = True
+                                break
+                            except:
+                                continue
 
-            names = found_args + ["t"]
+                        else:
+                            try:
+                                value = float(name)
+                                signals.append(value)
+                                found_args.append(arg)
+                                found_numeric = True
+                            except:
+                                continue
+
+                        if found_numeric:
+                            break
+
+            names = [*found_args, "t"]
 
             triggering = description.get("triggering", "triggering_on_all")
             if triggering == "triggering_on_all":
-                timestamps = [sig.timestamps for sig in signals]
+                timestamps = [sig.timestamps for sig in signals if not isinstance(sig, (int, float))]
 
                 if timestamps:
                     common_timebase = reduce(np.union1d, timestamps)
                 else:
                     common_timebase = all_timebase
-                signals = [sig.interp(common_timebase) for sig in signals]
+                signals = [sig.interp(common_timebase) if not isinstance(sig, (int, float)) else sig for sig in signals]
 
             elif triggering == "triggering_on_channel":
                 triggering_channel = description["triggering_value"]
@@ -455,12 +557,15 @@ def compute_signal(
                     common_timebase = measured_signals[triggering_channel].timestamps
                 else:
                     common_timebase = np.array([])
-                signals = [sig.interp(common_timebase) for sig in signals]
+                signals = [sig.interp(common_timebase) if not isinstance(sig, (int, float)) else sig for sig in signals]
             else:
                 step = float(description["triggering_value"])
 
                 common_timebase = []
                 for signal in signals:
+                    if isinstance(signal, (int, float)):
+                        continue
+
                     if len(signal):
                         common_timebase.append(signal.timestamps[0])
                         common_timebase.append(signal.timestamps[-1])
@@ -477,24 +582,36 @@ def compute_signal(
                 else:
                     common_timebase = np.array([])
 
-                signals = [sig.interp(common_timebase) for sig in signals]
+                signals = [sig.interp(common_timebase) if not isinstance(sig, (int, float)) else sig for sig in signals]
 
-            if (
-                description.get("computation_mode", "sample_by_sample")
-                == "sample_by_sample"
-            ):
+            if not isinstance(common_timebase, np.ndarray):
+                common_timebase = np.array(common_timebase)
+
+            for i, (signal, arg_name) in enumerate(zip(signals, found_args, strict=False)):
+                if isinstance(signal, (int, float)):
+                    value = signal
+                    signals[i] = Signal(
+                        name=arg_name, samples=np.full(len(common_timebase), value), timestamps=common_timebase
+                    )
+
+            if "time_stamps_shift" in description:
+                time_stamps_shift = description["time_stamps_shift"]
+                if time_stamps_shift["type"] == "fixed":
+                    shift = time_stamps_shift["fixed_timestamps_shift"]
+                else:
+                    shift_variable = time_stamps_shift["global_variable_timestamps_shift"]
+                    shift = numeric_global_variables.get(shift_variable, 0.0)
+            else:
+                shift = 0.0
+
+            if description.get("computation_mode", "sample_by_sample") == "sample_by_sample":
                 signals = [sig.samples.tolist() for sig in signals]
                 signals.append(common_timebase)
 
                 samples = []
-                for values in zip(*signals):
+                for values in zip(*signals, strict=False):
                     try:
-                        current_sample = func(
-                            **{
-                                arg_name: arg_val
-                                for arg_name, arg_val in zip(names, values)
-                            }
-                        )
+                        current_sample = func(**dict(zip(names, values, strict=False)))
                     except:
                         current_sample = COMPUTED_FUNCTION_ERROR_VALUE
                     samples.append(current_sample)
@@ -502,7 +619,7 @@ def compute_signal(
                 result = Signal(
                     name="_",
                     samples=samples,
-                    timestamps=common_timebase,
+                    timestamps=common_timebase + shift,
                     flags=Signal.Flags.computed,
                 )
 
@@ -511,11 +628,7 @@ def compute_signal(
 
                 signals.append(common_timebase)
 
-                not_found = [
-                    arg_name
-                    for arg_name in description["args"]
-                    if arg_name not in names
-                ]
+                not_found = [arg_name for arg_name in description["args"] if arg_name not in names]
 
                 not_found_signals = []
 
@@ -525,26 +638,19 @@ def compute_signal(
                     if arg_name in names:
                         continue
                     else:
-                        not_found_signals.append(
-                            np.ones(len(common_timebase), dtype="u1") * arg.default
-                        )
+                        not_found_signals.append(np.ones(len(common_timebase), dtype="u1") * arg.default)
 
                 names.extend(not_found)
                 signals.extend(not_found_signals)
 
-                samples = func(
-                    **{
-                        arg_name: arg_signal
-                        for arg_name, arg_signal in zip(names, signals)
-                    }
-                )
+                samples = func(**dict(zip(names, signals, strict=False)))
                 if len(samples) != len(common_timebase):
                     common_timebase = common_timebase[-len(samples) :]
 
                 result = Signal(
                     name="_",
                     samples=samples,
-                    timestamps=common_timebase,
+                    timestamps=common_timebase + shift,
                     flags=Signal.Flags.computed,
                 )
 
@@ -672,7 +778,7 @@ def computation_to_python_function(description):
         for match in VARIABLE.finditer(exp):
             name = match.group("var")
             if name not in translation:
-                arg = f"arg{len(translation)+1}"
+                arg = f"arg{len(translation) + 1}"
                 translation[name] = arg
                 args.append(f"{arg}=0")
                 fargs[arg] = [name.strip("}{")]
@@ -734,9 +840,7 @@ def computation_to_python_function(description):
                 "channel_comment": description["channel_comment"],
                 "channel_name": description["channel_name"],
                 "channel_unit": description["channel_unit"],
-                "computation_mode": description.get(
-                    "computation_mode", "sample_by_sample"
-                ),
+                "computation_mode": description.get("computation_mode", "sample_by_sample"),
                 "definition": definition,
                 "type": "python_function",
                 "triggering": "triggering_on_all",
@@ -745,9 +849,7 @@ def computation_to_python_function(description):
             }
         else:
             new_description = description
-            new_description["computation_mode"] = description.get(
-                "computation_mode", "sample_by_sample"
-            )
+            new_description["computation_mode"] = description.get("computation_mode", "sample_by_sample")
 
     return new_description
 
@@ -758,9 +860,7 @@ def replace_computation_dependency(computation, old_name, new_name):
         if isinstance(val, str) and old_name in val:
             new_computation[key] = val.replace(old_name, new_name)
         elif isinstance(val, dict):
-            new_computation[key] = replace_computation_dependency(
-                val, old_name, new_name
-            )
+            new_computation[key] = replace_computation_dependency(val, old_name, new_name)
         else:
             new_computation[key] = val
 
@@ -768,7 +868,7 @@ def replace_computation_dependency(computation, old_name, new_name):
 
 
 class HelperChannel:
-    __slots__ = "entry", "name", "added"
+    __slots__ = "added", "entry", "name"
 
     def __init__(self, entry, name):
         self.name = name
@@ -785,8 +885,9 @@ def copy_ranges(ranges):
                 color = range_info[color_name]
                 if isinstance(color, QtGui.QBrush):
                     range_info[color_name] = QtGui.QBrush(color)
-                elif isinstance(color, QtGui.QColor):
+                elif isinstance(color, (QtGui.QColor, str)):
                     range_info[color_name] = fn.mkColor(color)
+
             new_ranges.append(range_info)
 
         return new_ranges
@@ -831,9 +932,7 @@ def unique_ranges(ranges):
                 )
 
         ranges = []
-        for value1, value2, op1, op2, bk_color, ft_color in sorted(
-            new_ranges, key=compare
-        ):
+        for value1, value2, op1, op2, bk_color, ft_color in sorted(new_ranges, key=compare):
             if bk_color[0] == 0:
                 ranges.append(
                     {
@@ -860,9 +959,7 @@ def unique_ranges(ranges):
     return ranges
 
 
-def get_colors_using_ranges(
-    value, ranges, default_background_color, default_font_color
-):
+def get_colors_using_ranges(value, ranges, default_background_color, default_font_color):
     new_background_color = default_background_color
     new_font_color = default_font_color
 
@@ -1002,21 +1099,6 @@ def get_color_using_ranges(
         return new_color
 
 
-def timeit(func):
-    def timed(*args, **kwargs):
-        t1 = perf_counter()
-        ret = func(*args, **kwargs)
-        t2 = perf_counter()
-        delta = t2 - t1
-        if delta >= 1e-3:
-            print(f"CALL {func.__qualname__}: {delta*1e3:.3f} ms")
-        else:
-            print(f"CALL {func.__qualname__}: {delta*1e6:.3f} us")
-        return ret
-
-    return timed
-
-
 def value_as_bin(value, dtype):
     byte_string = np.array([value], dtype=dtype).tobytes()
     if dtype.byteorder != ">":
@@ -1024,8 +1106,7 @@ def value_as_bin(value, dtype):
 
     nibles = []
     for byte in byte_string:
-        nibles.append(f"{byte >> 4:04b}")
-        nibles.append(f"{byte & 0xf:04b}")
+        nibles.extend((f"{byte >> 4:04b}", f"{byte & 0xF:04b}"))
 
     return ".".join(nibles)
 
@@ -1056,17 +1137,18 @@ def value_as_str(value, format, dtype=None, precision=3):
         kind = "S"
 
     if kind in "ui":
-        if format == "bin":
-            string = value_as_bin(value, dtype)
-        elif format == "hex":
-            string = value_as_hex(value, dtype)
-        elif format == "ascii":
-            if 0 < value < 0x110000:
-                string = chr(value)
-            else:
+        match format:
+            case "bin":
+                string = value_as_bin(value, dtype)
+            case "hex":
+                string = value_as_hex(value, dtype)
+            case "ascii":
+                if 0 < value < 0x110000:
+                    string = chr(value)
+                else:
+                    string = str(value)
+            case _:
                 string = str(value)
-        else:
-            string = str(value)
     elif kind in "SUV":
         string = str(value)
     else:
@@ -1088,20 +1170,78 @@ def draw_color_icon(color):
     return QtGui.QIcon(pix)
 
 
-def generate_python_function(definition, in_globals=None):
+def contains_imports(string):
+    for line in string.splitlines():
+        if IMPORT.match(line) or FROM_IMPORT.match(line) or IMPORT_INNER.search(line) or FROM_INNER_IMPORT.search(line):
+            return True
+
+    return False
+
+
+def generate_python_variables(definition: str, in_globals: dict | None = None) -> str | None:
+    trace = None
+
+    if not isinstance(definition, str):
+        trace = "The function definition must be a string"
+
+    elif in_globals and not isinstance(in_globals, dict):
+        trace = "'in_globals' must be a dict"
+    else:
+        definition = definition.replace("\t", "    ")
+
+        if contains_imports(definition):
+            trace = "Cannot use import statements in the definition"
+        else:
+            _globals = in_globals or generate_python_function_globals()
+
+            try:
+                exec(definition, _globals)
+            except:
+                trace = format_exc()
+
+    return trace
+
+
+def generate_python_function_globals() -> dict:
+    func_globals = {
+        "bisect": bisect,
+        "collections": collections,
+        "itertools": itertools,
+        "math": math,
+        "np": np,
+        "pd": pd,
+        "random": random,
+        "struct": struct,
+        "__builtins__": _BUILTINS,
+    }
+    try:
+        import scipy as sp
+
+        func_globals["sp"] = sp
+    except ImportError:
+        pass
+
+    return func_globals
+
+
+def generate_python_function(definition: str, in_globals: dict | None = None) -> tuple:
     trace = None
     func = None
 
+    if not isinstance(definition, str):
+        trace = "The function definition must be a string"
+        return func, trace
+    if in_globals and not isinstance(in_globals, dict):
+        trace = "'in_globals' must be a dict"
+        return func, trace
+
     definition = definition.replace("\t", "    ")
 
-    _globals = in_globals or {}
-    _globals.update(
-        {
-            "math": math,
-            "np": np,
-            "pd": pd,
-        }
-    )
+    if contains_imports(definition):
+        trace = "Cannot use import statements in the definition"
+        return func, trace
+
+    _globals = in_globals or generate_python_function_globals()
 
     if not definition:
         trace = "The function definition must not be empty"
@@ -1151,61 +1291,90 @@ def generate_python_function(definition, in_globals=None):
 
 def check_generated_function(func, trace, function_source, silent, parent=None):
     if trace is not None:
-        ErrorDialog(
-            title="Function definition check",
-            message="The syntax is not correct. The following error was found",
-            trace=f"{trace}\n\nin the function\n\n{function_source}",
-            parent=parent,
-        ).exec()
+        if not silent:
+            ErrorDialog(
+                title="Function definition check",
+                message="The syntax is not correct. The following error was found",
+                trace=f"{trace}\n\nin the function\n\n{function_source}",
+                parent=parent,
+            ).exec()
         return False, None
 
     args = inspect.signature(func)
+
+    # try with sample by sample call
     kwargs = {}
     for i, (arg_name, arg) in enumerate(args.parameters.items()):
-        kwargs[arg_name] = random.randint(1, 2**64)
+        kwargs[arg_name] = arg.default
 
     trace = ""
 
-    # try with sample by sample call
     sample_by_sample = True
     try:
-        func(**kwargs)
+        res = func(**kwargs)
     except ZeroDivisionError:
         pass
     except:
         sample_by_sample = False
-        trace = format_exc()
+        trace = f"Sample by sample: {format_exc()}"
+    else:
+        if not isinstance(res, (int, float)):
+            sample_by_sample = False
+            trace = "Sample by sample: The function did not return a numeric scalar value"
 
+    # try with complete signal call
     kwargs = {}
     for i, (arg_name, arg) in enumerate(args.parameters.items()):
-        kwargs[arg_name] = np.ones(10000, dtype="i1") * random.randint(1, 2**64)
+        kwargs[arg_name] = np.ones(10000, dtype="i8") * arg.default
+    kwargs["t"] = np.arange(10000) * 0.1
 
-    # try with sample by sample call
     complete_signal = True
     try:
-        func(**kwargs)
+        res = func(**kwargs)
     except ZeroDivisionError:
         pass
     except:
         complete_signal = False
         if trace:
-            trace += "\n\n" + format_exc()
+            trace += f"\n\nComplete signal: {format_exc()}"
         else:
-            trace = format_exc()
+            trace = f"Complete signal: {format_exc()}"
+    else:
+        if not isinstance(res, (tuple, list, np.ndarray)):
+            complete_signal = False
+            if trace:
+                trace += "\n\nComplete signal: The function did not return an list, tuple or np.ndarray"
+            else:
+                trace = "Complete signal: The function did not return an list, tuple or np.ndarray"
+
+        try:
+            if len(np.array(res).shape) > 1:
+                complete_signal = False
+                if trace:
+                    trace += "\n\nComplete signal: The function returned a multi dimensional array"
+                else:
+                    trace = "Complete signal: The function returned a multi dimensional array"
+        except:
+            complete_signal = False
+            if trace:
+                trace += f"\n\nComplete signal: {format_exc()}"
+            else:
+                trace = f"Complete signal: {format_exc()}"
 
     if not sample_by_sample and not complete_signal:
-        ErrorDialog(
-            title="Function definition check",
-            message="The syntax is not correct. The following error was found",
-            trace=f"{trace}\n\nin the function\n\n{function_source}",
-            parent=parent,
-        ).exec()
+        if not silent:
+            ErrorDialog(
+                title="Function definition check",
+                message="The syntax is not correct. The following error was found",
+                trace=f"{trace}\n\nin the function\n\n{function_source}",
+                parent=parent,
+            ).exec()
 
         return False, None
 
     elif not sample_by_sample:
         if not silent:
-            QtWidgets.QMessageBox.information(
+            MessageBox.information(
                 parent,
                 "Function definition check",
                 "The function definition appears to be correct only for complete signal mode.",
@@ -1215,7 +1384,7 @@ def check_generated_function(func, trace, function_source, silent, parent=None):
 
     elif not complete_signal:
         if not silent:
-            QtWidgets.QMessageBox.information(
+            MessageBox.information(
                 parent,
                 "Function definition check",
                 "The function definition appears to be correct only for sample by sample mode.",
@@ -1224,7 +1393,7 @@ def check_generated_function(func, trace, function_source, silent, parent=None):
         return True, func
     else:
         if not silent:
-            QtWidgets.QMessageBox.information(
+            MessageBox.information(
                 parent,
                 "Function definition check",
                 "The function definition appears to be correct for both sample by sample and complete signal modes.",
@@ -1233,5 +1402,10 @@ def check_generated_function(func, trace, function_source, silent, parent=None):
         return True, func
 
 
+def set_app_user_model_id(app_user_model_id: str) -> None:
+    if sys.platform == "win32":
+        ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(app_user_model_id)
+
+
 if __name__ == "__main__":
     pass
