@@ -1,7 +1,5 @@
-# -*- coding: utf-8 -*-
 from PySide6 import QtWidgets
 
-from ..ui import resource_rc
 from ..ui.channel_info_widget import Ui_ChannelInfo
 
 
