@@ -1,13 +1,10 @@
-# -*- coding: utf-8 -*-
-
 import json
 from struct import pack
-from traceback import format_exc
 
 from natsort import natsorted
 from PySide6 import QtCore, QtGui, QtWidgets
 
-from ...blocks.utils import extract_mime_names
+from ..serde import extract_mime_names
 
 
 class ListWidget(QtWidgets.QListWidget):
@@ -23,9 +20,9 @@ class ListWidget(QtWidgets.QListWidget):
 
         self.details_enabled = False
 
-        self.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
-        self.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
-        self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.setDragDropMode(QtWidgets.QAbstractItemView.DragDropMode.InternalMove)
+        self.setSelectionMode(QtWidgets.QAbstractItemView.SelectionMode.ExtendedSelection)
+        self.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.CustomContextMenu)
         self.customContextMenuRequested.connect(self.open_menu)
 
         self.setAlternatingRowColors(True)
@@ -55,7 +52,7 @@ class ListWidget(QtWidgets.QListWidget):
         key = event.key()
         modifiers = event.modifiers()
 
-        if key == QtCore.Qt.Key_Delete and self.can_delete_items:
+        if key == QtCore.Qt.Key.Key_Delete and self.can_delete_items:
             selected_items = self.selectedItems()
             deleted = []
             for item in selected_items:
@@ -67,59 +64,62 @@ class ListWidget(QtWidgets.QListWidget):
                 self.takeItem(row)
             if deleted:
                 self.itemsDeleted.emit(deleted)
+            event.accept()
 
-        elif key == QtCore.Qt.Key_Space and modifiers == QtCore.Qt.NoModifier:
+        elif key == QtCore.Qt.Key.Key_Space and modifiers == QtCore.Qt.KeyboardModifier.NoModifier:
+            event.accept()
             selected_items = self.selectedItems()
             if not selected_items:
                 return
 
-            states = [
-                self.itemWidget(item).display.checkState() for item in selected_items
-            ]
+            states = [self.itemWidget(item).display.checkState() for item in selected_items]
 
-            if any(state == QtCore.Qt.Unchecked for state in states):
-                state = QtCore.Qt.Checked
+            if any(state == QtCore.Qt.CheckState.Unchecked for state in states):
+                state = QtCore.Qt.CheckState.Checked
             else:
-                state = QtCore.Qt.Unchecked
+                state = QtCore.Qt.CheckState.Unchecked
             for item in selected_items:
                 wid = self.itemWidget(item)
                 wid.display.setCheckState(state)
 
-        elif key == QtCore.Qt.Key_Space and modifiers == QtCore.Qt.ControlModifier:
+        elif key == QtCore.Qt.Key.Key_Space and modifiers == QtCore.Qt.KeyboardModifier.ControlModifier:
+            event.accept()
             selected_items = self.selectedItems()
             if not selected_items:
                 return
 
-            states = [
-                self.itemWidget(item).individual_axis.checkState()
-                for item in selected_items
-            ]
+            states = [self.itemWidget(item).individual_axis.checkState() for item in selected_items]
 
-            if any(state == QtCore.Qt.Unchecked for state in states):
-                state = QtCore.Qt.Checked
+            if any(state == QtCore.Qt.CheckState.Unchecked for state in states):
+                state = QtCore.Qt.CheckState.Checked
             else:
-                state = QtCore.Qt.Unchecked
+                state = QtCore.Qt.CheckState.Unchecked
             for item in selected_items:
                 wid = self.itemWidget(item)
                 wid.individual_axis.setCheckState(state)
 
-        elif modifiers == QtCore.Qt.ControlModifier and key == QtCore.Qt.Key_C:
+        elif modifiers == QtCore.Qt.KeyboardModifier.ControlModifier and key == QtCore.Qt.Key.Key_C:
             selected_items = self.selectedItems()
             if not selected_items:
+                event.accept()
                 return
+
             self.itemWidget(selected_items[0]).keyPressEvent(event)
 
         elif modifiers == (
-            QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier
-        ) and key in (QtCore.Qt.Key_C, QtCore.Qt.Key_P):
+            QtCore.Qt.KeyboardModifier.ControlModifier | QtCore.Qt.KeyboardModifier.ShiftModifier
+        ) and key in (
+            QtCore.Qt.Key.Key_C,
+            QtCore.Qt.Key.Key_P,
+        ):
             selected_items = self.selectedItems()
             if not selected_items:
+                event.accept()
                 return
             self.itemWidget(selected_items[0]).keyPressEvent(event)
 
         else:
             super().keyPressEvent(event)
-            self.parent().keyPressEvent(event)
 
     def startDrag(self, supportedActions):
         selected_items = self.selectedItems()
@@ -160,13 +160,11 @@ class ListWidget(QtWidgets.QListWidget):
                 )
             )
 
-        mimeData.setData(
-            "application/octet-stream-asammdf", QtCore.QByteArray(b"".join(data))
-        )
+        mimeData.setData("application/octet-stream-asammdf", QtCore.QByteArray(b"".join(data)))
 
         drag = QtGui.QDrag(self)
         drag.setMimeData(mimeData)
-        drag.exec(QtCore.Qt.CopyAction)
+        drag.exec(QtCore.Qt.DropAction.CopyAction)
 
     def dragEnterEvent(self, e):
         if e.mimeData().hasFormat("application/octet-stream-asammdf"):
@@ -192,38 +190,38 @@ class ListWidget(QtWidgets.QListWidget):
 
         else:
             menu = QtWidgets.QMenu()
-            menu.addAction(self.tr(f"{self.count()} items in the list"))
+            menu.addAction(f"{self.count()} items in the list")
             menu.addSeparator()
-            menu.addAction(self.tr("Copy name (Ctrl+C)"))
-            menu.addAction(self.tr("Copy display properties (Ctrl+Shift+C)"))
-            menu.addAction(self.tr("Paste display properties (Ctrl+Shift+P)"))
+            menu.addAction("Copy name (Ctrl+C)")
+            menu.addAction("Copy display properties (Ctrl+Shift+C)")
+            menu.addAction("Paste display properties (Ctrl+Shift+P)")
             menu.addSeparator()
-            menu.addAction(self.tr("Enable all"))
-            menu.addAction(self.tr("Disable all"))
-            menu.addAction(self.tr("Enable all but this"))
+            menu.addAction("Enable all")
+            menu.addAction("Disable all")
+            menu.addAction("Enable all but this")
             menu.addSeparator()
             if self._has_hidden_items:
                 show_hide = "Show disabled items"
             else:
                 show_hide = "Hide disabled items"
-            menu.addAction(self.tr(show_hide))
+            menu.addAction(show_hide)
             menu.addSeparator()
 
-            menu.addAction(self.tr("Add to common Y axis"))
-            menu.addAction(self.tr("Remove from common Y axis"))
+            menu.addAction("Add to common Y axis")
+            menu.addAction("Remove from common Y axis")
             menu.addSeparator()
-            menu.addAction(self.tr("Set unit"))
-            menu.addAction(self.tr("Set precision"))
+            menu.addAction("Set unit")
+            menu.addAction("Set precision")
             menu.addSeparator()
-            menu.addAction(self.tr("Relative time base shift"))
-            menu.addAction(self.tr("Set time base start offset"))
+            menu.addAction("Relative time base shift")
+            menu.addAction("Set time base start offset")
             menu.addSeparator()
-            menu.addAction(self.tr("Insert computation using this channel"))
+            menu.addAction("Insert computation using this channel")
             menu.addSeparator()
-            menu.addAction(self.tr("Delete (Del)"))
+            menu.addAction("Delete (Del)")
             menu.addSeparator()
-            menu.addAction(self.tr("Toggle details"))
-            menu.addAction(self.tr("File/Computation properties"))
+            menu.addAction("Toggle details")
+            menu.addAction("File/Computation properties")
 
             action = menu.exec_(self.viewport().mapToGlobal(position))
 
@@ -232,23 +230,23 @@ class ListWidget(QtWidgets.QListWidget):
 
         if action.text() == "Copy name (Ctrl+C)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier
+                QtCore.QEvent.Type.KeyPress, QtCore.Qt.Key.Key_C, QtCore.Qt.KeyboardModifier.ControlModifier
             )
             self.itemWidget(item).keyPressEvent(event)
 
         elif action.text() == "Copy display properties (Ctrl+Shift+C)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress,
-                QtCore.Qt.Key_C,
-                QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier,
+                QtCore.QEvent.Type.KeyPress,
+                QtCore.Qt.Key.Key_C,
+                QtCore.Qt.KeyboardModifier.ControlModifier | QtCore.Qt.KeyboardModifier.ShiftModifier,
             )
             self.itemWidget(item).keyPressEvent(event)
 
         elif action.text() == "Paste display properties (Ctrl+Shift+P)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress,
-                QtCore.Qt.Key_P,
-                QtCore.Qt.ControlModifier | QtCore.Qt.ShiftModifier,
+                QtCore.QEvent.Type.KeyPress,
+                QtCore.Qt.Key.Key_P,
+                QtCore.Qt.KeyboardModifier.ControlModifier | QtCore.Qt.KeyboardModifier.ShiftModifier,
             )
             self.itemWidget(item).keyPressEvent(event)
 
@@ -256,13 +254,13 @@ class ListWidget(QtWidgets.QListWidget):
             for i in range(self.count()):
                 item = self.item(i)
                 widget = self.itemWidget(item)
-                widget.display.setCheckState(QtCore.Qt.Checked)
+                widget.display.setCheckState(QtCore.Qt.CheckState.Checked)
 
         elif action.text() == "Disable all":
             for i in range(self.count()):
                 item = self.item(i)
                 widget = self.itemWidget(item)
-                widget.display.setCheckState(QtCore.Qt.Unchecked)
+                widget.display.setCheckState(QtCore.Qt.CheckState.Unchecked)
 
         elif action.text() == "Enable all but this":
             selected_items = self.selectedItems()
@@ -270,9 +268,9 @@ class ListWidget(QtWidgets.QListWidget):
                 item = self.item(i)
                 widget = self.itemWidget(item)
                 if item in selected_items:
-                    widget.display.setCheckState(QtCore.Qt.Unchecked)
+                    widget.display.setCheckState(QtCore.Qt.CheckState.Unchecked)
                 else:
-                    widget.display.setCheckState(QtCore.Qt.Checked)
+                    widget.display.setCheckState(QtCore.Qt.CheckState.Checked)
 
         elif action.text() == show_hide:
             if self._has_hidden_items:
@@ -294,7 +292,7 @@ class ListWidget(QtWidgets.QListWidget):
                 item = self.item(i)
                 widget = self.itemWidget(item)
                 if item in selected_items:
-                    widget.ylink.setCheckState(QtCore.Qt.Checked)
+                    widget.ylink.setCheckState(QtCore.Qt.CheckState.Checked)
 
         elif action.text() == "Remove from common Y axis":
             selected_items = self.selectedItems()
@@ -302,12 +300,12 @@ class ListWidget(QtWidgets.QListWidget):
                 item = self.item(i)
                 widget = self.itemWidget(item)
                 if item in selected_items:
-                    widget.ylink.setCheckState(QtCore.Qt.Unchecked)
+                    widget.ylink.setCheckState(QtCore.Qt.CheckState.Unchecked)
 
         elif action.text() == "Set unit":
             selected_items = self.selectedItems()
 
-            unit, ok = QtWidgets.QInputDialog.getText(None, "Set new unit", "Unit:")
+            unit, ok = QtWidgets.QInputDialog.getText(self, "Set new unit", "Unit:")
 
             if ok:
                 selected_items = self.selectedItems()
@@ -321,9 +319,7 @@ class ListWidget(QtWidgets.QListWidget):
         elif action.text() == "Set precision":
             selected_items = self.selectedItems()
 
-            precision, ok = QtWidgets.QInputDialog.getInt(
-                None, "Set new precision (float decimals)", "Precision:"
-            )
+            precision, ok = QtWidgets.QInputDialog.getInt(self, "Set new precision (float decimals)", "Precision:")
 
             if ok and 0 <= precision <= 15:
                 for i in range(self.count()):
@@ -360,11 +356,11 @@ class ListWidget(QtWidgets.QListWidget):
                         widget = self.itemWidget(item)
                         if item in selected_items:
                             uuids.append(widget.uuid)
-                    self.set_time_offset.emit([absolute, offset] + uuids)
+                    self.set_time_offset.emit([absolute, offset, *uuids])
 
         elif action.text() == "Delete (Del)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier
+                QtCore.QEvent.Type.KeyPress, QtCore.Qt.Key.Key_Delete, QtCore.Qt.KeyboardModifier.NoModifier
             )
             self.keyPressEvent(event)
 
@@ -390,19 +386,18 @@ class ListWidget(QtWidgets.QListWidget):
 
 
 class MinimalListWidget(QtWidgets.QListWidget):
-    itemsDeleted = QtCore.Signal(list)
     itemsDeleted = QtCore.Signal(list)
     itemsPasted = QtCore.Signal()
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self.setDragDropMode(QtWidgets.QAbstractItemView.InternalMove)
-        self.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
+        self.setDragDropMode(QtWidgets.QAbstractItemView.DragDropMode.InternalMove)
+        self.setSelectionMode(QtWidgets.QAbstractItemView.SelectionMode.ExtendedSelection)
 
         self.setAlternatingRowColors(True)
 
-        self.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.CustomContextMenu)
         self.customContextMenuRequested.connect(self.open_menu)
 
         self.setAcceptDrops(True)
@@ -431,7 +426,7 @@ class MinimalListWidget(QtWidgets.QListWidget):
     def keyPressEvent(self, event):
         key = event.key()
         modifiers = event.modifiers()
-        if key == QtCore.Qt.Key_Delete and self.user_editable:
+        if key == QtCore.Qt.Key.Key_Delete and self.user_editable:
             selected_items = self.selectedItems()
             deleted = []
 
@@ -467,7 +462,9 @@ class MinimalListWidget(QtWidgets.QListWidget):
             if deleted:
                 self.itemsDeleted.emit(deleted)
 
-        elif key == QtCore.Qt.Key_C and modifiers == QtCore.Qt.ControlModifier:
+            event.accept()
+
+        elif key == QtCore.Qt.Key.Key_C and modifiers == QtCore.Qt.KeyboardModifier.ControlModifier:
             text = []
             for item in self.selectedItems():
                 try:
@@ -481,9 +478,11 @@ class MinimalListWidget(QtWidgets.QListWidget):
                 text = ""
 
             QtWidgets.QApplication.instance().clipboard().setText(text)
+            event.accept()
+
         elif (
-            key == QtCore.Qt.Key_V
-            and modifiers == QtCore.Qt.ControlModifier
+            key == QtCore.Qt.Key.Key_V
+            and modifiers == QtCore.Qt.KeyboardModifier.ControlModifier
             and self.user_editable
         ):
             lines = QtWidgets.QApplication.instance().clipboard().text().splitlines()
@@ -493,6 +492,7 @@ class MinimalListWidget(QtWidgets.QListWidget):
                     self.itemsPasted.emit()
                 except:
                     pass
+            event.accept()
         else:
             super().keyPressEvent(event)
 
@@ -501,25 +501,26 @@ class MinimalListWidget(QtWidgets.QListWidget):
 
         if self.minimal_menu:
             if self.count() > 0:
-                menu.addAction(self.tr(f"{self.count()} items in the list"))
-                menu.addSeparator()
-                menu.addAction(self.tr("Delete (Del)"))
+                menu.addAction(f"{self.count()} items in the list")
+                if self.user_editable:
+                    menu.addSeparator()
+                    menu.addAction("Delete (Del)")
             else:
                 return
         else:
             if self.count() == 0:
-                menu.addAction(self.tr(f"{self.count()} items in the list"))
+                menu.addAction(f"{self.count()} items in the list")
                 menu.addSeparator()
                 if self.user_editable:
-                    menu.addAction(self.tr("Paste names (Ctrl+V)"))
+                    menu.addAction("Paste names (Ctrl+V)")
             else:
-                menu.addAction(self.tr(f"{self.count()} items in the list"))
+                menu.addAction(f"{self.count()} items in the list")
                 menu.addSeparator()
-                menu.addAction(self.tr("Copy names (Ctrl+C)"))
+                menu.addAction("Copy names (Ctrl+C)")
                 if self.user_editable:
-                    menu.addAction(self.tr("Paste names (Ctrl+V)"))
+                    menu.addAction("Paste names (Ctrl+V)")
                     menu.addSeparator()
-                    menu.addAction(self.tr("Delete (Del)"))
+                    menu.addAction("Delete (Del)")
 
         action = menu.exec_(self.viewport().mapToGlobal(position))
 
@@ -528,17 +529,17 @@ class MinimalListWidget(QtWidgets.QListWidget):
 
         if action.text() == "Delete (Del)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier
+                QtCore.QEvent.Type.KeyPress, QtCore.Qt.Key.Key_Delete, QtCore.Qt.KeyboardModifier.NoModifier
             )
             self.keyPressEvent(event)
         elif action.text() == "Copy names (Ctrl+C)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier
+                QtCore.QEvent.Type.KeyPress, QtCore.Qt.Key.Key_C, QtCore.Qt.KeyboardModifier.ControlModifier
             )
             self.keyPressEvent(event)
         elif action.text() == "Paste names (Ctrl+V)":
             event = QtGui.QKeyEvent(
-                QtCore.QEvent.KeyPress, QtCore.Qt.Key_V, QtCore.Qt.ControlModifier
+                QtCore.QEvent.Type.KeyPress, QtCore.Qt.Key.Key_V, QtCore.Qt.KeyboardModifier.ControlModifier
             )
             self.keyPressEvent(event)
 
@@ -551,7 +552,27 @@ class MinimalListWidget(QtWidgets.QListWidget):
             painter.setPen(col)
             fm = self.fontMetrics()
             elided_text = fm.elidedText(
-                self.placeholder_text, QtCore.Qt.ElideRight, self.viewport().width()
+                self.placeholder_text, QtCore.Qt.TextElideMode.ElideRight, self.viewport().width()
             )
-            painter.drawText(self.viewport().rect(), QtCore.Qt.AlignCenter, elided_text)
+            painter.drawText(self.viewport().rect(), QtCore.Qt.AlignmentFlag.AlignCenter, elided_text)
             painter.restore()
+
+    def search(self, attribute="", value=None):
+        index = None
+        count = self.count()
+        for row in range(count):
+            item = self.item(row)
+
+            if hasattr(item, attribute):
+                if getattr(item, attribute) == value:
+                    index = row
+                    break
+            else:
+                widget = self.itemWidget(item)
+
+                if hasattr(widget, attribute):
+                    if getattr(widget, attribute) == value:
+                        index = row
+                        break
+
+        return index
