@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from functools import partial
 import logging
 import webbrowser
@@ -6,7 +5,6 @@ import webbrowser
 import pyqtgraph as pg
 from PySide6 import QtCore, QtGui, QtWidgets
 
-from ..ui import resource_rc
 from .plot import Plot, PlotSignal
 
 bin_ = bin
@@ -99,75 +97,67 @@ class PlotWindow(QtWidgets.QMainWindow):
         plot_actions = QtGui.QActionGroup(self)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/fit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(QtGui.QPixmap(":/fit.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, f"{'Fit trace': <20}\tF", menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_F))
-        action.setShortcut(QtCore.Qt.Key_F)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_F))
+        action.setShortcut(QtCore.Qt.Key.Key_F)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/grid.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(QtGui.QPixmap(":/grid.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tG".format("Grid"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_G))
-        action.setShortcut(QtCore.Qt.Key_G)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_G))
+        action.setShortcut(QtCore.Qt.Key.Key_G)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/home.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(QtGui.QPixmap(":/home.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tH".format("Home"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_H))
-        action.setShortcut(QtCore.Qt.Key_H)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_H))
+        action.setShortcut(QtCore.Qt.Key.Key_H)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(
-            QtGui.QPixmap(":/list2.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-        )
+        icon.addPixmap(QtGui.QPixmap(":/list2.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tS".format("Stack"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_S))
-        action.setShortcut(QtCore.Qt.Key_S)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_S))
+        action.setShortcut(QtCore.Qt.Key.Key_S)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(
-            QtGui.QPixmap(":/zoom-in.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-        )
+        icon.addPixmap(QtGui.QPixmap(":/zoom-in.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tI".format("Zoom in"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_I))
-        action.setShortcut(QtCore.Qt.Key_I)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_I))
+        action.setShortcut(QtCore.Qt.Key.Key_I)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(
-            QtGui.QPixmap(":/zoom-out.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-        )
+        icon.addPixmap(QtGui.QPixmap(":/zoom-out.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tO".format("Zoom out"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_O))
-        action.setShortcut(QtCore.Qt.Key_O)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_O))
+        action.setShortcut(QtCore.Qt.Key.Key_O)
         plot_actions.addAction(action)
 
         action = QtGui.QAction("{: <20}\t.".format("Toggle dots"), menu)
-        action.triggered.connect(partial(self.toggle_dots, key=QtCore.Qt.Key_O))
-        action.setShortcut(QtCore.Qt.Key_Period)
+        action.triggered.connect(partial(self.toggle_dots, key=QtCore.Qt.Key.Key_O))
+        action.setShortcut(QtCore.Qt.Key.Key_Period)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/plus.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(QtGui.QPixmap(":/plus.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tIns".format("Insert computation"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_Insert))
-        action.setShortcut(QtCore.Qt.Key_Insert)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_Insert))
+        action.setShortcut(QtCore.Qt.Key.Key_Insert)
         plot_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
-        action = QtGui.QAction(
-            icon, "{: <20}\tCtrl+S".format("Save active subplot channels"), menu
-        )
+        icon.addPixmap(QtGui.QPixmap(":/save.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
+        action = QtGui.QAction(icon, "{: <20}\tCtrl+S".format("Save active subplot channels"), menu)
         action.triggered.connect(
             partial(
                 self.plot_action,
-                key=QtCore.Qt.Key_S,
-                modifier=QtCore.Qt.ControlModifier,
+                key=QtCore.Qt.Key.Key_S,
+                modifier=QtCore.Qt.KeyboardModifier.ControlModifier,
             )
         )
         action.setShortcut(QtGui.QKeySequence("Ctrl+S"))
@@ -181,8 +171,8 @@ class PlotWindow(QtWidgets.QMainWindow):
         action.triggered.connect(
             partial(
                 self.plot_action,
-                key=QtCore.Qt.Key_H,
-                modifier=QtCore.Qt.ControlModifier,
+                key=QtCore.Qt.Key.Key_H,
+                modifier=QtCore.Qt.KeyboardModifier.ControlModifier,
             )
         )
         action.setShortcut(QtGui.QKeySequence("Ctrl+H"))
@@ -192,8 +182,8 @@ class PlotWindow(QtWidgets.QMainWindow):
         action.triggered.connect(
             partial(
                 self.plot_action,
-                key=QtCore.Qt.Key_B,
-                modifier=QtCore.Qt.ControlModifier,
+                key=QtCore.Qt.Key.Key_B,
+                modifier=QtCore.Qt.KeyboardModifier.ControlModifier,
             )
         )
         action.setShortcut(QtGui.QKeySequence("Ctrl+B"))
@@ -203,8 +193,8 @@ class PlotWindow(QtWidgets.QMainWindow):
         action.triggered.connect(
             partial(
                 self.plot_action,
-                key=QtCore.Qt.Key_P,
-                modifier=QtCore.Qt.ControlModifier,
+                key=QtCore.Qt.Key.Key_P,
+                modifier=QtCore.Qt.KeyboardModifier.ControlModifier,
             )
         )
         action.setShortcut(QtGui.QKeySequence("Ctrl+P"))
@@ -216,18 +206,14 @@ class PlotWindow(QtWidgets.QMainWindow):
 
         action = QtGui.QAction("{: <20}\tAlt+R".format("Raw samples"), menu)
         action.triggered.connect(
-            partial(
-                self.plot_action, key=QtCore.Qt.Key_R, modifier=QtCore.Qt.AltModifier
-            )
+            partial(self.plot_action, key=QtCore.Qt.Key.Key_R, modifier=QtCore.Qt.KeyboardModifier.AltModifier)
         )
         action.setShortcut(QtGui.QKeySequence("Alt+R"))
         samples_format_actions.addAction(action)
 
         action = QtGui.QAction("{: <20}\tAlt+S".format("Scaled samples"), menu)
         action.triggered.connect(
-            partial(
-                self.plot_action, key=QtCore.Qt.Key_S, modifier=QtCore.Qt.AltModifier
-            )
+            partial(self.plot_action, key=QtCore.Qt.Key.Key_S, modifier=QtCore.Qt.KeyboardModifier.AltModifier)
         )
         action.setShortcut(QtGui.QKeySequence("Alt+S"))
         samples_format_actions.addAction(action)
@@ -237,9 +223,9 @@ class PlotWindow(QtWidgets.QMainWindow):
         info = QtGui.QActionGroup(self)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/info.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(QtGui.QPixmap(":/info.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tM".format("Statistics"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_M))
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_M))
         action.setShortcut(QtGui.QKeySequence("M"))
         info.addAction(action)
 
@@ -247,60 +233,48 @@ class PlotWindow(QtWidgets.QMainWindow):
         cursors_actions = QtGui.QActionGroup(self)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(
-            QtGui.QPixmap(":/cursor.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-        )
+        icon.addPixmap(QtGui.QPixmap(":/cursor.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tC".format("Cursor"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_C))
-        action.setShortcut(QtCore.Qt.Key_C)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_C))
+        action.setShortcut(QtCore.Qt.Key.Key_C)
         cursors_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(
-            QtGui.QPixmap(":/right.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-        )
+        icon.addPixmap(QtGui.QPixmap(":/right.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\t←".format("Move cursor left"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_Left))
-        action.setShortcut(QtCore.Qt.Key_Left)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_Left))
+        action.setShortcut(QtCore.Qt.Key.Key_Left)
         cursors_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/left.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(QtGui.QPixmap(":/left.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\t→".format("Move cursor right"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_Right))
-        action.setShortcut(QtCore.Qt.Key_Right)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_Right))
+        action.setShortcut(QtCore.Qt.Key.Key_Right)
         cursors_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(
-            QtGui.QPixmap(":/range.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-        )
+        icon.addPixmap(QtGui.QPixmap(":/range.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tR".format("Range"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_R))
-        action.setShortcut(QtCore.Qt.Key_R)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_R))
+        action.setShortcut(QtCore.Qt.Key.Key_R)
         cursors_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(
-            QtGui.QPixmap(":/lock_range.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-        )
+        icon.addPixmap(QtGui.QPixmap(":/lock_range.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         action = QtGui.QAction(icon, "{: <20}\tY".format("Lock/unlock range"), menu)
-        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_Y))
-        action.setShortcut(QtCore.Qt.Key_Y)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key.Key_Y))
+        action.setShortcut(QtCore.Qt.Key.Key_Y)
         cursors_actions.addAction(action)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(
-            QtGui.QPixmap(":/comments.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off
-        )
-        action = QtGui.QAction(
-            icon, "{: <20}\tCtrl+I".format("Insert cursor comment"), menu
-        )
+        icon.addPixmap(QtGui.QPixmap(":/comments.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
+        action = QtGui.QAction(icon, "{: <20}\tCtrl+I".format("Insert cursor comment"), menu)
         action.triggered.connect(
             partial(
                 self.plot_action,
-                key=QtCore.Qt.Key_I,
-                modifier=QtCore.Qt.ControlModifier,
+                key=QtCore.Qt.Key.Key_I,
+                modifier=QtCore.Qt.KeyboardModifier.ControlModifier,
             )
         )
         action.setShortcut(QtGui.QKeySequence("Ctrl+I"))
@@ -309,9 +283,7 @@ class PlotWindow(QtWidgets.QMainWindow):
         icon = QtGui.QIcon()
         action = QtGui.QAction("{: <20}\tAlt+I".format("Toggle trigger texts"), menu)
         action.triggered.connect(
-            partial(
-                self.plot_action, key=QtCore.Qt.Key_I, modifier=QtCore.Qt.AltModifier
-            )
+            partial(self.plot_action, key=QtCore.Qt.Key.Key_I, modifier=QtCore.Qt.KeyboardModifier.AltModifier)
         )
         action.setShortcut(QtGui.QKeySequence("Alt+I"))
         cursors_actions.addAction(action)
@@ -338,14 +310,14 @@ class PlotWindow(QtWidgets.QMainWindow):
         self.setCentralWidget(self.plot)
 
         icon = QtGui.QIcon()
-        icon.addPixmap(QtGui.QPixmap(":/info.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        icon.addPixmap(QtGui.QPixmap(":/info.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
         self.setWindowIcon(icon)
 
         self.show()
         self.plot.add_new_channels(signals)
 
-    def plot_action(self, key, modifier=QtCore.Qt.NoModifier):
-        event = QtGui.QKeyEvent(QtCore.QEvent.KeyPress, key, modifier)
+    def plot_action(self, key, modifier=QtCore.Qt.KeyboardModifier.NoModifier):
+        event = QtGui.QKeyEvent(QtCore.QEvent.Type.KeyPress, key, modifier)
         self.plot.keyPressEvent(event)
 
     def toggle_dots(self, key):
@@ -389,149 +361,145 @@ class PlotWindow(QtWidgets.QMainWindow):
         else:
             palette = QtGui.QPalette()
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.WindowText, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Button, brush)
             brush = QtGui.QBrush(QtGui.QColor(82, 82, 82))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Light, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Light, brush)
             brush = QtGui.QBrush(QtGui.QColor(68, 68, 68))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Midlight, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Midlight, brush)
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Dark, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Dark, brush)
             brush = QtGui.QBrush(QtGui.QColor(36, 36, 36))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Mid, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Mid, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Text, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Text, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.BrightText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.BrightText, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.ButtonText, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Base, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Window, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Shadow, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.Shadow, brush)
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.AlternateBase, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.AlternateBase, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 220))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ToolTipBase, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.ToolTipBase, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ToolTipText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.ToolTipText, brush)
 
             brush = QtGui.QBrush(QtGui.QColor(100, 100, 100))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Highlight, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Highlight, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.WindowText, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Button, brush)
             brush = QtGui.QBrush(QtGui.QColor(82, 82, 82))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Light, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Light, brush)
             brush = QtGui.QBrush(QtGui.QColor(68, 68, 68))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Midlight, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Midlight, brush)
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Dark, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Dark, brush)
             brush = QtGui.QBrush(QtGui.QColor(36, 36, 36))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Mid, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Mid, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Text, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Text, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.BrightText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.BrightText, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.ButtonText, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Base, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Window, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Shadow, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.Shadow, brush)
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(
-                QtGui.QPalette.Inactive, QtGui.QPalette.AlternateBase, brush
-            )
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.AlternateBase, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 220))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ToolTipBase, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.ToolTipBase, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ToolTipText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.ToolTipText, brush)
 
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.WindowText, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Button, brush)
             brush = QtGui.QBrush(QtGui.QColor(82, 82, 82))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Light, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Light, brush)
             brush = QtGui.QBrush(QtGui.QColor(68, 68, 68))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Midlight, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Midlight, brush)
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Dark, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Dark, brush)
             brush = QtGui.QBrush(QtGui.QColor(36, 36, 36))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Mid, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Mid, brush)
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Text, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Text, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.BrightText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.BrightText, brush)
             brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.ButtonText, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Base, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Window, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Shadow, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.Shadow, brush)
             brush = QtGui.QBrush(QtGui.QColor(55, 55, 55))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(
-                QtGui.QPalette.Disabled, QtGui.QPalette.AlternateBase, brush
-            )
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.AlternateBase, brush)
             brush = QtGui.QBrush(QtGui.QColor(255, 255, 220))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ToolTipBase, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.ToolTipBase, brush)
             brush = QtGui.QBrush(QtGui.QColor(0, 0, 0))
-            brush.setStyle(QtCore.Qt.SolidPattern)
-            palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ToolTipText, brush)
+            brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
+            palette.setBrush(QtGui.QPalette.ColorGroup.Disabled, QtGui.QPalette.ColorRole.ToolTipText, brush)
             app.setPalette(palette)
 
     def help(self, event):
