@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
 import numpy as np
-from PySide6 import QtCore, QtGui, QtWidgets
+from PySide6 import QtWidgets
 
-from ..ui import resource_rc
 from ..ui.vtt_widget import Ui_VTT_Widget
 
 
@@ -37,9 +35,7 @@ class VTTWidget(Ui_VTT_Widget, QtWidgets.QWidget):
         self.conversion_btn.clicked.connect(self.edit_conversion)
 
     def edit_conversion(self):
-        dlg = ConversionEditor(
-            f"Raw={self.value.value()} referenced", self.conversion, parent=self
-        )
+        dlg = ConversionEditor(f"Raw={self.value.value()} referenced", self.conversion, parent=self)
         dlg.exec_()
         if dlg.pressed_button == "apply":
             self.conversion = dlg.conversion()
