@@ -8,11 +8,11 @@ from asammdf.blocks.utils import MdfException
 
 
 class TestSignal(unittest.TestCase):
-    def test_init_empty(self):
+    def test_init_empty(self) -> None:
         s = Signal([], [], name="s")
         self.assertEqual(len(s), 0)
 
-    def test_init_errors(self):
+    def test_init_errors(self) -> None:
         with self.assertRaises(MdfException):
             Signal([], [1], name="s")
         with self.assertRaises(MdfException):
@@ -28,7 +28,7 @@ class TestSignal(unittest.TestCase):
         with self.assertRaises(MdfException):
             Signal(np.array([]), np.array([]))
 
-    def test_cut_int(self):
+    def test_cut_int(self) -> None:
         s = Signal(np.arange(5), np.arange(5, dtype="<f8"), name="S")
 
         res = s.cut()
@@ -55,15 +55,11 @@ class TestSignal(unittest.TestCase):
 
         res = s.cut(start=0.5)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0.5, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0.5, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=0.5, include_ends=False)
         self.assertTrue(np.array_equal([1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=4)
         self.assertTrue(np.array_equal([4], res.samples))
@@ -109,27 +105,19 @@ class TestSignal(unittest.TestCase):
 
         res = s.cut(stop=4)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(stop=4, include_ends=False)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(stop=4.1)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(stop=4.1, include_ends=False)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         # with start and stop
 
@@ -159,9 +147,7 @@ class TestSignal(unittest.TestCase):
 
         res = s.cut(start=-2, stop=1.1)
         self.assertTrue(np.array_equal([0, 1, 1], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 1.1], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 1.1], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=-2, stop=1.1, include_ends=False)
         self.assertTrue(np.array_equal([0, 1], res.samples))
@@ -177,21 +163,15 @@ class TestSignal(unittest.TestCase):
 
         res = s.cut(start=0.1, stop=3.5)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 3], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0.1, 1, 2, 3, 3.5], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0.1, 1, 2, 3, 3.5], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=0.1, stop=3.5, include_ends=False)
         self.assertTrue(np.array_equal([1, 2, 3], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([1, 2, 3], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([1, 2, 3], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=1.1, stop=1.9)
         self.assertTrue(np.array_equal([1, 1], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([1.1, 1.9], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([1.1, 1.9], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=1.1, stop=1.9, include_ends=False)
         self.assertTrue(np.array_equal([], res.samples))
@@ -221,7 +201,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal([], res.samples))
         self.assertTrue(np.array_equal(np.array([], dtype="<f8"), res.timestamps))
 
-    def test_cut_float(self):
+    def test_cut_float(self) -> None:
         s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         res = s.cut()
@@ -248,15 +228,11 @@ class TestSignal(unittest.TestCase):
 
         res = s.cut(start=0.5)
         self.assertTrue(np.allclose([0.5, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0.5, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0.5, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=0.5, include_ends=False)
         self.assertTrue(np.array_equal([1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=4)
         self.assertTrue(np.array_equal([4], res.samples))
@@ -302,27 +278,19 @@ class TestSignal(unittest.TestCase):
 
         res = s.cut(stop=4)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(stop=4, include_ends=False)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(stop=4.1)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         res = s.cut(stop=4.1, include_ends=False)
         self.assertTrue(np.array_equal([0, 1, 2, 3, 4], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 2, 3, 4], dtype="<f8"), res.timestamps))
 
         # with start and stop
 
@@ -352,9 +320,7 @@ class TestSignal(unittest.TestCase):
 
         res = s.cut(start=-2, stop=1.1)
         self.assertTrue(np.allclose([0, 1, 1.1], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([0, 1, 1.1], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([0, 1, 1.1], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=-2, stop=1.1, include_ends=False)
         self.assertTrue(np.array_equal([0, 1], res.samples))
@@ -370,15 +336,11 @@ class TestSignal(unittest.TestCase):
 
         res = s.cut(start=0.1, stop=3.5)
         self.assertTrue(np.allclose([0.1, 1, 2, 3, 3.5], res.samples))
-        self.assertTrue(
-            np.allclose(np.array([0.1, 1, 2, 3, 3.5], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.allclose(np.array([0.1, 1, 2, 3, 3.5], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=0.1, stop=3.5, include_ends=False)
         self.assertTrue(np.array_equal([1, 2, 3], res.samples))
-        self.assertTrue(
-            np.array_equal(np.array([1, 2, 3], dtype="<f8"), res.timestamps)
-        )
+        self.assertTrue(np.array_equal(np.array([1, 2, 3], dtype="<f8"), res.timestamps))
 
         res = s.cut(start=1.1, stop=1.9)
         self.assertTrue(np.allclose([1.1, 1.9], res.samples))
@@ -412,7 +374,7 @@ class TestSignal(unittest.TestCase):
         self.assertTrue(np.array_equal([], res.samples))
         self.assertTrue(np.array_equal(np.array([], dtype="<f8"), res.timestamps))
 
-    def test_add(self):
+    def test_add(self) -> None:
         s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         target = np.arange(0, 10, 2, dtype="<f4")
@@ -439,7 +401,7 @@ class TestSignal(unittest.TestCase):
         res = s
         self.assertTrue(np.array_equal(res.samples, target))
 
-    def test_sub(self):
+    def test_sub(self) -> None:
         s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         target = np.zeros(5, dtype="<f4")
@@ -466,7 +428,7 @@ class TestSignal(unittest.TestCase):
         res = s
         self.assertTrue(np.array_equal(res.samples, target))
 
-    def test_mul(self):
+    def test_mul(self) -> None:
         s = Signal(np.arange(5, dtype="<f4"), np.arange(5, dtype="<f8"), name="S")
 
         target = np.arange(5, dtype="<f4") ** 2
@@ -491,7 +453,7 @@ class TestSignal(unittest.TestCase):
         res = s
         self.assertTrue(np.array_equal(res.samples, target))
 
-    def test_div(self):
+    def test_div(self) -> None:
         s = Signal(np.arange(1, 5, dtype="<f4"), np.arange(1, 5, dtype="<f8"), name="S")
 
         target = np.ones(4, dtype="<f4")
@@ -513,7 +475,7 @@ class TestSignal(unittest.TestCase):
         res = s
         self.assertTrue(np.array_equal(res.samples, target))
 
-    def test_pow(self):
+    def test_pow(self) -> None:
         s = Signal(np.arange(1, 5, dtype="<f4"), np.arange(1, 5, dtype="<f8"), name="S")
 
         target = np.arange(1, 5, dtype="<f4") ** 3
