@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 from io import BytesIO
+import typing
 import unittest
 
 from asammdf.blocks.utils import MdfException
@@ -7,9 +8,15 @@ from asammdf.blocks.v4_blocks import TextBlock
 
 
 class TestATBLOCK(unittest.TestCase):
-    @classmethod
-    def setUpClass(cls):
+    plain_text: str
+    plain_bytes: bytes
+    plain_stream: BytesIO
+    meta_text: str
+    meta_bytes: bytes
+    meta_stream: BytesIO
 
+    @classmethod
+    def setUpClass(cls) -> None:
         cls.plain_text = "sample text"
         cls.plain_bytes = b"##TX\x00\x00\x00\x00(\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00sample text\x00\x00\x00\x00\x00"
         cls.plain_stream = BytesIO()
@@ -20,12 +27,14 @@ class TestATBLOCK(unittest.TestCase):
         cls.meta_stream = BytesIO()
         cls.meta_stream.write(cls.meta_bytes)
 
-    def test_read(self):
+    def test_read(self) -> None:
         self.plain_stream.seek(0)
 
         block = TextBlock(address=0, stream=self.plain_stream)
 
         self.assertEqual(block.id, b"##TX")
+        self.assertIsInstance(block.text, bytes)
+        block.text = typing.cast(bytes, block.text)
         self.assertEqual(block.text.strip(b"\0").decode("utf-8"), self.plain_text)
 
         self.meta_stream.seek(0)
@@ -33,9 +42,11 @@ class TestATBLOCK(unittest.TestCase):
         block = TextBlock(address=0, stream=self.meta_stream)
 
         self.assertEqual(block.id, b"##MD")
+        self.assertIsInstance(block.text, bytes)
+        block.text = typing.cast(bytes, block.text)
         self.assertEqual(block.text.strip(b"\0").decode("utf-8"), self.meta_text)
 
-    def test_read_wrong_id(self):
+    def test_read_wrong_id(self) -> None:
         stream = BytesIO(self.plain_bytes)
         stream.seek(0)
         stream.write(b"_NOK")
@@ -43,8 +54,7 @@ class TestATBLOCK(unittest.TestCase):
         with self.assertRaises(MdfException):
             TextBlock(address=0, stream=stream)
 
-    def test_bytes(self):
-
+    def test_bytes(self) -> None:
         block = TextBlock(text=self.plain_text, meta=False)
         self.assertEqual(bytes(block), self.plain_bytes)
 
